@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,11 +7,11 @@
 #pragma once
 
 #include "file.h"
-#include "libruqola_private_export.h"
+#include "libruqolacore_export.h"
 #include <QDebug>
 #include <QList>
 
-class LIBRUQOLACORE_TESTS_EXPORT FileAttachments
+class LIBRUQOLACORE_EXPORT FileAttachments
 {
 public:
     FileAttachments();
@@ -36,6 +36,8 @@ public:
     void parseFileAttachments(const QJsonObject &fileAttachmentsObj);
     void parseMoreFileAttachments(const QJsonObject &fileAttachmentsObj);
 
+    void addFileAttachments(const QList<File> &fileAttachments);
+
 private:
     LIBRUQOLACORE_NO_EXPORT void parseFiles(const QJsonObject &fileAttachmentsObj);
     QList<File> mFileAttachments;
