@@ -1,11 +1,11 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "blockactiontest.h"
-#include "messages/blockaction.h"
+#include "messages/block/blockaction.h"
 #include <QTest>
 QTEST_GUILESS_MAIN(BlockActionTest)
 
@@ -22,6 +22,7 @@ void BlockActionTest::shouldHaveDefaultValues()
     QVERIFY(b.type().isEmpty());
     QVERIFY(b.blockId().isEmpty());
     QVERIFY(b.value().isEmpty());
+    QVERIFY(b.url().isEmpty());
     QVERIFY(!b.isValid());
 }
 
