@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "fileattachmentstest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "attachments/fileattachments.h"
 #include <QTest>
 QTEST_GUILESS_MAIN(FileAttachmentsTest)
@@ -31,7 +33,7 @@ void FileAttachmentsTest::shouldLoadThreads_data()
     QTest::addColumn<int>("total");
     QTest::addColumn<int>("offset");
 
-    QTest::addRow("empty") << QStringLiteral("threads-empty") << 0 << 0 << 0;
+    QTest::addRow("empty") << u"threads-empty"_s << 0 << 0 << 0;
 }
 
 void FileAttachmentsTest::shouldLoadThreads()
