@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #include "managelocaldatabasetest.h"
 #include "managelocaldatabase.h"
 #include <QTest>
-QTEST_MAIN(ManageLocalDatabaseTest)
+QTEST_GUILESS_MAIN(ManageLocalDatabaseTest)
 ManageLocalDatabaseTest::ManageLocalDatabaseTest(QObject *parent)
     : QObject{parent}
 {
