@@ -5,12 +5,14 @@
 */
 
 #include "messageattachmenttest.h"
+
 #include "messages/messageattachment.h"
 #include <QJsonObject>
 #include <QStandardPaths>
 #include <QTest>
-QTEST_GUILESS_MAIN(MessageAttachmentTest)
 
+using namespace Qt::Literals::StringLiterals;
+QTEST_GUILESS_MAIN(MessageAttachmentTest)
 MessageAttachmentTest::MessageAttachmentTest(QObject *parent)
     : QObject(parent)
 {
@@ -35,20 +37,21 @@ void MessageAttachmentTest::shouldHaveDefaultValue()
     QVERIFY(!attachment.showAttachment());
     QVERIFY(!attachment.hasDescription());
     QCOMPARE(attachment.attachmentSize(), -1);
+    QVERIFY(attachment.format().isEmpty());
 }
 
 void MessageAttachmentTest::shouldSerializeData()
 {
     {
         MessageAttachment input;
-        input.setColor(QStringLiteral("foo1"));
-        input.setDescription(QStringLiteral("foo2"));
-        input.setTitle(QStringLiteral("foo3"));
-        input.setLink(QStringLiteral("foo4"));
+        input.setColor(u"foo1"_s);
+        input.setDescription(u"foo2"_s);
+        input.setTitle(u"foo3"_s);
+        input.setLink(u"foo4"_s);
         input.setImageHeight(53);
         input.setImageWidth(83);
         input.setAttachmentSize(454564);
-        input.setAuthorName(QStringLiteral("auth"));
+        input.setAuthorName(u"auth"_s);
         input.generateTitle();
         const QJsonObject ba = MessageAttachment::serialize(input);
         const MessageAttachment output = MessageAttachment::deserialize(ba);
@@ -57,9 +60,9 @@ void MessageAttachmentTest::shouldSerializeData()
 
     {
         MessageAttachment input;
-        input.setDescription(QStringLiteral("foo2"));
-        input.setTitle(QStringLiteral("foo3"));
-        input.setLink(QStringLiteral("foo4"));
+        input.setDescription(u"foo2"_s);
+        input.setTitle(u"foo3"_s);
+        input.setLink(u"foo4"_s);
         input.generateTitle();
         const QJsonObject ba = MessageAttachment::serialize(input);
         const MessageAttachment output = MessageAttachment::deserialize(ba);
@@ -68,11 +71,11 @@ void MessageAttachmentTest::shouldSerializeData()
 
     {
         MessageAttachment input;
-        input.setColor(QStringLiteral("foo1"));
-        input.setDescription(QStringLiteral("foo2"));
-        input.setTitle(QStringLiteral("foo3"));
-        input.setLink(QStringLiteral("foo4"));
-        input.setAuthorName(QStringLiteral("auth"));
+        input.setColor(u"foo1"_s);
+        input.setDescription(u"foo2"_s);
+        input.setTitle(u"foo3"_s);
+        input.setLink(u"foo4"_s);
+        input.setAuthorName(u"auth"_s);
         input.generateTitle();
         const QJsonObject ba = MessageAttachment::serialize(input);
         const MessageAttachment output = MessageAttachment::deserialize(ba);
@@ -83,13 +86,13 @@ void MessageAttachmentTest::shouldSerializeData()
 void MessageAttachmentTest::shouldAllowToDownloadAttachment()
 {
     MessageAttachment input;
-    input.setColor(QStringLiteral("foo1"));
-    input.setDescription(QStringLiteral("foo2"));
-    input.setTitle(QStringLiteral("foo3"));
-    input.setLink(QStringLiteral("http://www.kde.org"));
-    input.setAuthorName(QStringLiteral("auth"));
+    input.setColor(u"foo1"_s);
+    input.setDescription(u"foo2"_s);
+    input.setTitle(u"foo3"_s);
+    input.setLink(u"http://www.kde.org"_s);
+    input.setAuthorName(u"auth"_s);
     QVERIFY(!input.canDownloadAttachment());
-    input.setLink(QStringLiteral("bla"));
+    input.setLink(u"bla"_s);
     QVERIFY(input.canDownloadAttachment());
 }
 
