@@ -45,11 +45,11 @@ void MessageTest::shouldParseMessage_data()
     {
         Message firstMessageRef;
         firstMessageRef.setMessageId("blaid"_ba);
-        firstMessageRef.setAlias(QStringLiteral("aliasname"));
+        firstMessageRef.setAlias(u"aliasname"_s);
         firstMessageRef.setGroupable(false);
         firstMessageRef.setTimeStamp(1504509615057);
-        firstMessageRef.setUsername(QStringLiteral("foo.ff"));
-        firstMessageRef.setName(QStringLiteral("newname"));
+        firstMessageRef.setUsername(u"foo.ff"_s);
+        firstMessageRef.setName(u"newname"_s);
         firstMessageRef.setUserId("qt9uNY9FxyL5QT5no"_ba);
         firstMessageRef.setMessageType(Message::NormalText);
         firstMessageRef.setUpdatedAt(1504509615063);
@@ -57,8 +57,8 @@ void MessageTest::shouldParseMessage_data()
         firstMessageRef.setIsStarred(false);
         firstMessageRef.setRoomId("qt9uNY9FxyL5QT5nouKK39zoewTkdacidH"_ba);
         MessageAttachment att;
-        att.setLink(QStringLiteral("/file-upload/3zfLR3Cjr8YnvD6cS/dd.pdf"));
-        att.setTitle(QStringLiteral("dd.pdf"));
+        att.setLink(u"/file-upload/3zfLR3Cjr8YnvD6cS/dd.pdf"_s);
+        att.setTitle(u"dd.pdf"_s);
         att.setAttachmentType(MessageAttachment::AttachmentType::File);
         att.generateTitle();
 
@@ -68,29 +68,29 @@ void MessageTest::shouldParseMessage_data()
         attachments.setMessageAttachments(attachmentInfos);
 
         firstMessageRef.setAttachments(attachments);
-        QTest::addRow("first") << QStringLiteral("first") << firstMessageRef;
+        QTest::addRow("first") << u"first"_s << firstMessageRef;
     }
     {
         Message urlMessageRef;
         urlMessageRef.setMessageId("9kHnbbjbHKHjXXQp7"_ba);
-        urlMessageRef.setAlias(QStringLiteral("alias"));
+        urlMessageRef.setAlias(u"alias"_s);
         urlMessageRef.setGroupable(false);
-        urlMessageRef.setName(QStringLiteral("name"));
+        urlMessageRef.setName(u"name"_s);
         urlMessageRef.setTimeStamp(1504596899771);
-        urlMessageRef.setUsername(QStringLiteral("username"));
+        urlMessageRef.setUsername(u"username"_s);
         urlMessageRef.setUserId("bjBueJtHsHQECdkmH"_ba);
         urlMessageRef.setMessageType(Message::NormalText);
         urlMessageRef.setUpdatedAt(1504596901803);
         urlMessageRef.setEditedAt(-1);
         urlMessageRef.setIsStarred(false);
         urlMessageRef.setRoomId("dBWXYy4nyBHn8Q7dv"_ba);
-        urlMessageRef.setText(QStringLiteral("https://foo.com/event/whoa"));
+        urlMessageRef.setText(u"https://foo.com/event/whoa"_s);
         MessageUrl url;
-        url.setUrl(QStringLiteral("https://foo.com/event/C8CT"));
-        url.setPageTitle(QStringLiteral("Trainers Panel I"));
-        url.setDescription(QStringLiteral("View more about this event at CppCon 2017"));
-        url.setImageUrl(QStringLiteral("http://foo.com/img/app-icon.png?1504596901"));
-        url.setSiteUrl(QStringLiteral("https://foo.com/event/C8CT"));
+        url.setUrl(u"https://foo.com/event/C8CT"_s);
+        url.setPageTitle(u"Trainers Panel I"_s);
+        url.setDescription(u"View more about this event at CppCon 2017"_s);
+        url.setImageUrl(u"http://foo.com/img/app-icon.png?1504596901"_s);
+        url.setSiteUrl(u"https://foo.com/event/C8CT"_s);
         url.setUrlId("9kHnbbjbHKHjXXQp7_0"_ba);
         url.setImageWidth(200);
         url.setImageHeight(200);
@@ -99,15 +99,15 @@ void MessageTest::shouldParseMessage_data()
         u.setMessageUrls({url});
         urlMessageRef.setUrls(u);
 
-        QTest::addRow("url") << QStringLiteral("url") << urlMessageRef;
+        QTest::addRow("url") << u"url"_s << urlMessageRef;
     }
     {
         Message urlMessageRef;
         urlMessageRef.setMessageId("yZPPxBQ79M9jG5hS6"_ba);
         urlMessageRef.setGroupable(false);
-        urlMessageRef.setName(QStringLiteral("test1 test2"));
+        urlMessageRef.setName(u"test1 test2"_s);
         urlMessageRef.setTimeStamp(1704484544725);
-        urlMessageRef.setUsername(QStringLiteral("test1"));
+        urlMessageRef.setUsername(u"test1"_s);
         urlMessageRef.setUserId("uKK39zoekdacidH"_ba);
         urlMessageRef.setMessageType(Message::NormalText);
         urlMessageRef.setUpdatedAt(1704484544886);
@@ -115,14 +115,14 @@ void MessageTest::shouldParseMessage_data()
         urlMessageRef.setIsStarred(false);
         urlMessageRef.setParseUrls(true);
         urlMessageRef.setRoomId("wWTrQstz3mex5Mm"_ba);
-        urlMessageRef.setText(QStringLiteral("https://foo/pull/48/files#diff-142b45cf8aa373eab25fd7a81c45c11fb2bb07e4556b34162497ecb66b4aefb4R149"));
+        urlMessageRef.setText(u"https://foo/pull/48/files#diff-142b45cf8aa373eab25fd7a81c45c11fb2bb07e4556b34162497ecb66b4aefb4R149"_s);
         MessageUrl url;
-        url.setUrl(QStringLiteral("https://foo/pull/48/files#diff-142b45cf8aa373eab25fd7a81c45c11fb2bb07e4556b34162497ecb66b4aefb4R149"));
-        url.setPageTitle(QStringLiteral("Deferred connection evaluation by blabla · Pull Request #48 · "));
-        url.setDescription(QStringLiteral("Closes #23"));
-        url.setImageUrl(QStringLiteral("https://avatar.foo.com/u/84974957?s=400&v=4"));
-        url.setSiteUrl(QStringLiteral("https://foo/pull/48"));
-        url.setSiteName(QStringLiteral("GitHub"));
+        url.setUrl(u"https://foo/pull/48/files#diff-142b45cf8aa373eab25fd7a81c45c11fb2bb07e4556b34162497ecb66b4aefb4R149"_s);
+        url.setPageTitle(u"Deferred connection evaluation by blabla · Pull Request #48 · "_s);
+        url.setDescription(u"Closes #23"_s);
+        url.setImageUrl(u"https://avatar.foo.com/u/84974957?s=400&v=4"_s);
+        url.setSiteUrl(u"https://foo/pull/48"_s);
+        url.setSiteName(u"GitHub"_s);
         url.setImageWidth(1200);
         url.setImageHeight(600);
         url.setUrlId("yZPPxBQ79M9jG5hS6_0"_ba);
@@ -130,17 +130,17 @@ void MessageTest::shouldParseMessage_data()
         MessageUrls u;
         u.setMessageUrls({url});
         urlMessageRef.setUrls(u);
-        QTest::addRow("url1") << QStringLiteral("url1") << urlMessageRef;
+        QTest::addRow("url1") << u"url1"_s << urlMessageRef;
     }
     {
         // Image
         Message imageMessageRef;
         imageMessageRef.setMessageId("CD2LsyS4dNbj6TTjQ"_ba);
-        imageMessageRef.setAlias(QStringLiteral("aliasname"));
-        imageMessageRef.setName(QStringLiteral("name"));
+        imageMessageRef.setAlias(u"aliasname"_s);
+        imageMessageRef.setName(u"name"_s);
         imageMessageRef.setGroupable(false);
         imageMessageRef.setTimeStamp(1505399177844);
-        imageMessageRef.setUsername(QStringLiteral("username"));
+        imageMessageRef.setUsername(u"username"_s);
         imageMessageRef.setUserId("FwHz8w8PWWQRqrJjM"_ba);
         imageMessageRef.setMessageType(Message::NormalText);
         imageMessageRef.setUpdatedAt(1505399177846);
@@ -149,10 +149,10 @@ void MessageTest::shouldParseMessage_data()
         imageMessageRef.setRoomId("dBWXYy4nyBHn8Q7dv"_ba);
 
         MessageAttachment attImage;
-        attImage.setTitle(QStringLiteral("Clipboard"));
-        attImage.setLink(QStringLiteral("/file-upload/Kt7DBWPe7pnadXDQH/test file"));
-        attImage.setImageUrlPreview(QStringLiteral("/file-upload/Kt7DBWPe7pnadXDQH/test file"));
-        attImage.setMimeType(QStringLiteral("image/png"));
+        attImage.setTitle(u"Clipboard"_s);
+        attImage.setLink(u"/file-upload/Kt7DBWPe7pnadXDQH/test file"_s);
+        attImage.setImageUrlPreview(u"/file-upload/Kt7DBWPe7pnadXDQH/test file"_s);
+        attImage.setMimeType(u"image/png"_s);
         attImage.setImageWidth(120);
         attImage.setImageHeight(120);
         attImage.setAttachmentType(MessageAttachment::AttachmentType::Image);
@@ -166,7 +166,7 @@ void MessageTest::shouldParseMessage_data()
 
         imageMessageRef.setAttachments(attachments);
 
-        QTest::addRow("image") << QStringLiteral("image") << imageMessageRef;
+        QTest::addRow("image") << u"image"_s << imageMessageRef;
         // TODO add Mentions
     }
 
@@ -174,11 +174,11 @@ void MessageTest::shouldParseMessage_data()
         // Video
         Message videoMessageRef;
         videoMessageRef.setMessageId("KCy2KiFYmS5NuakPm"_ba);
-        videoMessageRef.setAlias(QStringLiteral("Laurent Montel"));
-        videoMessageRef.setName(QStringLiteral("Laurent Montel"));
+        videoMessageRef.setAlias(u"Laurent Montel"_s);
+        videoMessageRef.setName(u"Laurent Montel"_s);
         videoMessageRef.setGroupable(false);
         videoMessageRef.setTimeStamp(1515580853098);
-        videoMessageRef.setUsername(QStringLiteral("laurent"));
+        videoMessageRef.setUsername(u"laurent"_s);
         videoMessageRef.setUserId("uKK39zoewTkdacidH"_ba);
         videoMessageRef.setMessageType(Message::NormalText);
         videoMessageRef.setUpdatedAt(1515580853102);
@@ -187,9 +187,9 @@ void MessageTest::shouldParseMessage_data()
         videoMessageRef.setRoomId("kGtPa6bu7xHrS5xz6"_ba);
 
         MessageAttachment attVideo;
-        attVideo.setTitle(QStringLiteral("SampleVideo_1280x720_1mb.mp4"));
-        attVideo.setLink(QStringLiteral("/file-upload/sLgmaWowyttg4d2ZD/SampleVideo_1280x720_1mb.mp4"));
-        attVideo.setDescription(QStringLiteral("test"));
+        attVideo.setTitle(u"SampleVideo_1280x720_1mb.mp4"_s);
+        attVideo.setLink(u"/file-upload/sLgmaWowyttg4d2ZD/SampleVideo_1280x720_1mb.mp4"_s);
+        attVideo.setDescription(u"test"_s);
         attVideo.setAttachmentSize(1055736);
         attVideo.setAttachmentType(MessageAttachment::AttachmentType::Video);
         attVideo.generateTitle();
@@ -202,17 +202,17 @@ void MessageTest::shouldParseMessage_data()
         // Add video size/video type etc.
         videoMessageRef.setAttachments(attachments);
 
-        QTest::addRow("video") << QStringLiteral("video") << videoMessageRef;
+        QTest::addRow("video") << u"video"_s << videoMessageRef;
     }
     {
         // Audio
         Message audioMessageRef;
         audioMessageRef.setMessageId("AwDsjWKJaW2wCP2ht"_ba);
-        audioMessageRef.setAlias(QStringLiteral("Laurent Montel"));
-        audioMessageRef.setName(QStringLiteral("Laurent Montel"));
+        audioMessageRef.setAlias(u"Laurent Montel"_s);
+        audioMessageRef.setName(u"Laurent Montel"_s);
         audioMessageRef.setGroupable(false);
         audioMessageRef.setTimeStamp(1515588347098);
-        audioMessageRef.setUsername(QStringLiteral("laurent"));
+        audioMessageRef.setUsername(u"laurent"_s);
         audioMessageRef.setUserId("uKK39zoewTkdacidH"_ba);
         audioMessageRef.setMessageType(Message::NormalText);
         audioMessageRef.setUpdatedAt(1515588347102);
@@ -221,9 +221,9 @@ void MessageTest::shouldParseMessage_data()
         audioMessageRef.setRoomId("kGtPa6bu7xHrS5xz6"_ba);
 
         MessageAttachment attAudio;
-        attAudio.setTitle(QStringLiteral("joint.wav"));
-        attAudio.setLink(QStringLiteral("/file-upload/9E8YBGgq3H6GbASf3/joint.wav"));
-        attAudio.setDescription(QStringLiteral("dfgsdfgsdfg sdfgd dfsg sfd g"));
+        attAudio.setTitle(u"joint.wav"_s);
+        attAudio.setLink(u"/file-upload/9E8YBGgq3H6GbASf3/joint.wav"_s);
+        attAudio.setDescription(u"dfgsdfgsdfg sdfgd dfsg sfd g"_s);
         attAudio.setAttachmentType(MessageAttachment::AttachmentType::Audio);
         attAudio.setAttachmentSize(59217);
         attAudio.generateTitle();
@@ -236,37 +236,37 @@ void MessageTest::shouldParseMessage_data()
         // Add video size/video type etc.
         audioMessageRef.setAttachments(attachments);
 
-        QTest::addRow("audio") << QStringLiteral("audio") << audioMessageRef;
+        QTest::addRow("audio") << u"audio"_s << audioMessageRef;
     }
     {
         // Message Starred
         Message messageStarredRef;
         messageStarredRef.setMessageId("R6AkSJ7orEkYHNcZJ"_ba);
-        messageStarredRef.setAlias(QStringLiteral("Laurent"));
-        messageStarredRef.setName(QStringLiteral("Laurent"));
+        messageStarredRef.setAlias(u"Laurent"_s);
+        messageStarredRef.setName(u"Laurent"_s);
         messageStarredRef.setGroupable(false);
         messageStarredRef.setTimeStamp(1516711967347);
-        messageStarredRef.setUsername(QStringLiteral("laurent"));
+        messageStarredRef.setUsername(u"laurent"_s);
         messageStarredRef.setUserId("uKK39zoewTkdacidH"_ba);
         messageStarredRef.setMessageType(Message::NormalText);
         messageStarredRef.setUpdatedAt(1516721464681);
         messageStarredRef.setEditedAt(1516712012309);
-        messageStarredRef.setEditedByUsername(QStringLiteral("laurent"));
+        messageStarredRef.setEditedByUsername(u"laurent"_s);
         messageStarredRef.setRoomId("kGtPa6bu7xHrS5xz6"_ba);
         messageStarredRef.setIsStarred(true);
-        messageStarredRef.setText(QStringLiteral("sefssssdfsefdsdfsd"));
+        messageStarredRef.setText(u"sefssssdfsefdsdfsd"_s);
 
-        QTest::addRow("messagestarred") << QStringLiteral("messagestarred") << messageStarredRef;
+        QTest::addRow("messagestarred") << u"messagestarred"_s << messageStarredRef;
     }
     {
         // Message Starred
         Message messagePinnedRef;
         messagePinnedRef.setMessageId("4eawfwyFnt7L8wTwE"_ba);
-        messagePinnedRef.setAlias(QStringLiteral("Laurent"));
-        messagePinnedRef.setName(QStringLiteral("Laurent Montel"));
+        messagePinnedRef.setAlias(u"Laurent"_s);
+        messagePinnedRef.setName(u"Laurent Montel"_s);
         messagePinnedRef.setGroupable(false);
         messagePinnedRef.setTimeStamp(1550240990669);
-        messagePinnedRef.setUsername(QStringLiteral("laurent"));
+        messagePinnedRef.setUsername(u"laurent"_s);
         messagePinnedRef.setUserId("uKK39zoewTkdacidH"_ba);
         messagePinnedRef.setMessageType(Message::NormalText);
         messagePinnedRef.setUpdatedAt(1550240994061);
@@ -274,42 +274,42 @@ void MessageTest::shouldParseMessage_data()
         messagePinnedRef.setIsStarred(false);
         MessagePinned pinned;
         pinned.setPinned(true);
-        pinned.setPinnedBy(QStringLiteral("laurent"));
+        pinned.setPinnedBy(u"laurent"_s);
         messagePinnedRef.setMessagePinned(pinned);
-        messagePinnedRef.setText(QStringLiteral("sdfgsdfg"));
+        messagePinnedRef.setText(u"sdfgsdfg"_s);
 
-        QTest::addRow("messagepinned") << QStringLiteral("messagepinned") << messagePinnedRef;
+        QTest::addRow("messagepinned") << u"messagepinned"_s << messagePinnedRef;
     }
 
     {
         // Message Remove Starred status
         Message messageStarredRemovedRef;
         messageStarredRemovedRef.setMessageId("R6AkSJ7orEkYHNcZJ"_ba);
-        messageStarredRemovedRef.setAlias(QStringLiteral("Laurent"));
-        messageStarredRemovedRef.setName(QStringLiteral("Laurent"));
+        messageStarredRemovedRef.setAlias(u"Laurent"_s);
+        messageStarredRemovedRef.setName(u"Laurent"_s);
         messageStarredRemovedRef.setGroupable(false);
         messageStarredRemovedRef.setTimeStamp(1516711967347);
-        messageStarredRemovedRef.setUsername(QStringLiteral("laurent"));
+        messageStarredRemovedRef.setUsername(u"laurent"_s);
         messageStarredRemovedRef.setUserId("uKK39zoewTkdacidH"_ba);
         messageStarredRemovedRef.setMessageType(Message::NormalText);
         messageStarredRemovedRef.setUpdatedAt(1516721464681);
         messageStarredRemovedRef.setEditedAt(1516712012309);
-        messageStarredRemovedRef.setEditedByUsername(QStringLiteral("laurent"));
+        messageStarredRemovedRef.setEditedByUsername(u"laurent"_s);
         messageStarredRemovedRef.setRoomId("kGtPa6bu7xHrS5xz6"_ba);
         messageStarredRemovedRef.setIsStarred(false);
-        messageStarredRemovedRef.setText(QStringLiteral("sefssssdfsefdsdfsd"));
+        messageStarredRemovedRef.setText(u"sefssssdfsefdsdfsd"_s);
 
-        QTest::addRow("messageremovedstarred") << QStringLiteral("messageremovedstarred") << messageStarredRemovedRef;
+        QTest::addRow("messageremovedstarred") << u"messageremovedstarred"_s << messageStarredRemovedRef;
     }
     {
         // messageattachmentfile
         Message messageAttachmentFileRef;
         messageAttachmentFileRef.setMessageId("messageid"_ba);
-        messageAttachmentFileRef.setAlias(QStringLiteral("Laurent"));
-        messageAttachmentFileRef.setName(QStringLiteral("Laurent Montel"));
+        messageAttachmentFileRef.setAlias(u"Laurent"_s);
+        messageAttachmentFileRef.setName(u"Laurent Montel"_s);
         messageAttachmentFileRef.setGroupable(false);
         messageAttachmentFileRef.setTimeStamp(1520540888833);
-        messageAttachmentFileRef.setUsername(QStringLiteral("laurent"));
+        messageAttachmentFileRef.setUsername(u"laurent"_s);
         messageAttachmentFileRef.setUserId("39zoewTkdacidH"_ba);
         messageAttachmentFileRef.setMessageType(Message::NormalText);
         messageAttachmentFileRef.setUpdatedAt(1520540888836);
@@ -318,9 +318,9 @@ void MessageTest::shouldParseMessage_data()
         messageAttachmentFileRef.setIsStarred(false);
 
         MessageAttachment fileAttachment;
-        fileAttachment.setTitle(QStringLiteral("webkit.txt"));
-        fileAttachment.setLink(QStringLiteral("/file-upload/tmqfdJTCmJ3oqG/webkit.txt"));
-        fileAttachment.setDescription(QStringLiteral("description"));
+        fileAttachment.setTitle(u"webkit.txt"_s);
+        fileAttachment.setLink(u"/file-upload/tmqfdJTCmJ3oqG/webkit.txt"_s);
+        fileAttachment.setDescription(u"description"_s);
         fileAttachment.setAttachmentType(MessageAttachment::AttachmentType::File);
         fileAttachment.generateTitle();
 
@@ -332,7 +332,7 @@ void MessageTest::shouldParseMessage_data()
         // Add video size/video type etc.
         messageAttachmentFileRef.setAttachments(attachments);
 
-        QTest::addRow("messageattachmentfile") << QStringLiteral("messageattachmentfile") << messageAttachmentFileRef;
+        QTest::addRow("messageattachmentfile") << u"messageattachmentfile"_s << messageAttachmentFileRef;
     }
 }
 
@@ -365,25 +365,25 @@ void MessageTest::shouldSerializeData()
 
         input.setMessageId("ff"_ba);
         input.setRoomId("room1"_ba);
-        input.setText(QStringLiteral("message1"));
+        input.setText(u"message1"_s);
         input.setTimeStamp(42);
-        input.setUsername(QStringLiteral("user1"));
+        input.setUsername(u"user1"_s);
         input.setUserId("userid1"_ba);
         input.setUpdatedAt(45);
         input.setEditedAt(89);
-        input.setEditedByUsername(QStringLiteral("editeduser1"));
-        input.setAlias(QStringLiteral("ali"));
-        input.setAvatar(QStringLiteral("avatar1"));
+        input.setEditedByUsername(u"editeduser1"_s);
+        input.setAlias(u"ali"_s);
+        input.setAvatar(u"avatar1"_s);
         input.setSystemMessageType(SystemMessageTypeUtil::MessageDeleted);
-        input.setLocalTranslation(QStringLiteral("Local !!!!"));
+        input.setLocalTranslation(u"Local !!!!"_s);
         input.setParseUrls(true);
-        input.setRole(QStringLiteral("leader"));
+        input.setRole(u"leader"_s);
         input.setMessageType(Message::MessageType::NormalText);
         input.setDiscussionRoomId("discussion111"_ba);
         input.setDiscussionCount(90);
         input.setDiscussionLastMessage(985);
         MessageTranslations l;
-        l.setTranslatedString({{QStringLiteral("foo"), QStringLiteral("bla")}});
+        l.setTranslatedString({{u"foo"_s, u"bla"_s}});
         input.setMessageTranslation(l);
         // It will break as it's not supported yet
         input.setIsStarred(true);
@@ -407,34 +407,34 @@ void MessageTest::shouldSerializeData()
 
         input.setMessageId("ff"_ba);
         input.setRoomId("room1"_ba);
-        input.setText(QStringLiteral("message1"));
+        input.setText(u"message1"_s);
         input.setTimeStamp(42);
-        input.setUsername(QStringLiteral("user1"));
+        input.setUsername(u"user1"_s);
         input.setUserId("userid1"_ba);
         input.setUpdatedAt(45);
         input.setEditedAt(89);
-        input.setEditedByUsername(QStringLiteral("editeduser1"));
-        input.setAlias(QStringLiteral("ali"));
-        input.setAvatar(QStringLiteral("avatar1"));
+        input.setEditedByUsername(u"editeduser1"_s);
+        input.setAlias(u"ali"_s);
+        input.setAvatar(u"avatar1"_s);
         input.setSystemMessageType(SystemMessageTypeUtil::MessageDeleted);
         input.setGroupable(true);
         input.setParseUrls(true);
-        input.setRole(QStringLiteral("leader"));
+        input.setRole(u"leader"_s);
         input.setMessageType(Message::MessageType::NormalText);
         // It will break as it's not supported yet
         input.setIsStarred(true);
 
         QList<MessageAttachment> lstAttachement;
         MessageAttachment attachment;
-        attachment.setDescription(QStringLiteral("foo1"));
-        attachment.setTitle(QStringLiteral("foo2"));
-        attachment.setLink(QStringLiteral("foo3"));
+        attachment.setDescription(u"foo1"_s);
+        attachment.setTitle(u"foo2"_s);
+        attachment.setLink(u"foo3"_s);
         attachment.generateTitle();
         lstAttachement.append(std::move(attachment));
         MessageAttachment attachment2;
-        attachment2.setDescription(QStringLiteral("foo5"));
-        attachment2.setTitle(QStringLiteral("foo6"));
-        attachment2.setLink(QStringLiteral("foo7"));
+        attachment2.setDescription(u"foo5"_s);
+        attachment2.setTitle(u"foo6"_s);
+        attachment2.setLink(u"foo7"_s);
         attachment2.generateTitle();
         lstAttachement.append(std::move(attachment2));
 
@@ -447,14 +447,14 @@ void MessageTest::shouldSerializeData()
 
         QList<MessageUrl> lstUrls;
         MessageUrl url1;
-        url1.setUrl(QStringLiteral("foo1"));
-        url1.setPageTitle(QStringLiteral("foo2"));
+        url1.setUrl(u"foo1"_s);
+        url1.setPageTitle(u"foo2"_s);
         url1.generateMessageUrlInfo();
         url1.setUrlId("ff_0"_ba);
         lstUrls.append(std::move(url1));
         MessageUrl url2;
-        url2.setUrl(QStringLiteral("foo5"));
-        url2.setPageTitle(QStringLiteral("foo6"));
+        url2.setUrl(u"foo5"_s);
+        url2.setPageTitle(u"foo6"_s);
         url2.generateMessageUrlInfo();
         url2.setUrlId("ff_1"_ba);
         lstUrls.append(std::move(url2));
@@ -479,19 +479,19 @@ void MessageTest::shouldSerializeData()
 
         input.setMessageId("ff"_ba);
         input.setRoomId("room1"_ba);
-        input.setText(QStringLiteral("message1"));
+        input.setText(u"message1"_s);
         input.setTimeStamp(42);
-        input.setUsername(QStringLiteral("user1"));
+        input.setUsername(u"user1"_s);
         input.setUserId("userid1"_ba);
         input.setUpdatedAt(45);
         input.setEditedAt(89);
-        input.setEditedByUsername(QStringLiteral("editeduser1"));
-        input.setAlias(QStringLiteral("ali"));
-        input.setAvatar(QStringLiteral("avatar1"));
+        input.setEditedByUsername(u"editeduser1"_s);
+        input.setAlias(u"ali"_s);
+        input.setAvatar(u"avatar1"_s);
         input.setSystemMessageType(SystemMessageTypeUtil::MessageDeleted);
-        input.setLocalTranslation(QStringLiteral("Local !!!!"));
+        input.setLocalTranslation(u"Local !!!!"_s);
         input.setParseUrls(true);
-        input.setRole(QStringLiteral("leader"));
+        input.setRole(u"leader"_s);
         input.setMessageType(Message::MessageType::NormalText);
         input.setThreadMessageId("thread111"_ba);
         input.setThreadCount(56);
@@ -512,19 +512,19 @@ void MessageTest::shouldSerializeData()
 
         input.setMessageId("ff"_ba);
         input.setRoomId("room1"_ba);
-        input.setText(QStringLiteral("message1"));
+        input.setText(u"message1"_s);
         input.setTimeStamp(42);
-        input.setUsername(QStringLiteral("user1"));
+        input.setUsername(u"user1"_s);
         input.setUserId("userid1"_ba);
         input.setUpdatedAt(45);
         input.setEditedAt(89);
-        input.setEditedByUsername(QStringLiteral("editeduser1"));
-        input.setAlias(QStringLiteral("ali"));
-        input.setAvatar(QStringLiteral("avatar1"));
+        input.setEditedByUsername(u"editeduser1"_s);
+        input.setAlias(u"ali"_s);
+        input.setAvatar(u"avatar1"_s);
         input.setSystemMessageType(SystemMessageTypeUtil::MessageDeleted);
         input.setGroupable(true);
         input.setParseUrls(true);
-        input.setRole(QStringLiteral("leader"));
+        input.setRole(u"leader"_s);
         input.setMessageType(Message::MessageType::NormalText);
         // It will break as it's not supported yet
         input.setIsStarred(true);
@@ -533,17 +533,17 @@ void MessageTest::shouldSerializeData()
         QList<MessageAttachment> lstAttachement;
         {
             MessageAttachment attachment;
-            attachment.setDescription(QStringLiteral("foo1"));
-            attachment.setTitle(QStringLiteral("foo2"));
-            attachment.setLink(QStringLiteral("foo3"));
+            attachment.setDescription(u"foo1"_s);
+            attachment.setTitle(u"foo2"_s);
+            attachment.setLink(u"foo3"_s);
             attachment.generateTitle();
             lstAttachement.append(std::move(attachment));
         }
         MessageAttachment attachment2;
         {
-            attachment2.setDescription(QStringLiteral("foo5"));
-            attachment2.setTitle(QStringLiteral("foo6"));
-            attachment2.setLink(QStringLiteral("foo7"));
+            attachment2.setDescription(u"foo5"_s);
+            attachment2.setTitle(u"foo6"_s);
+            attachment2.setLink(u"foo7"_s);
             attachment2.generateTitle();
             lstAttachement.append(std::move(attachment2));
         }
@@ -558,15 +558,15 @@ void MessageTest::shouldSerializeData()
 #if 0 // TODO FIXME
         {
             MessageUrl url1;
-            url1.setUrl(QStringLiteral("foo1"));
-            url1.setPageTitle(QStringLiteral("foo2"));
+            url1.setUrl(u"foo1"_s);
+            url1.setPageTitle(u"foo2"_s);
             url1.generateMessageUrlInfo();
             lstUrls.append(std::move(url1));
         }
         {
             MessageUrl url2;
-            url2.setUrl(QStringLiteral("foo5"));
-            url2.setPageTitle(QStringLiteral("foo6"));
+            url2.setUrl(u"foo5"_s);
+            url2.setPageTitle(u"foo6"_s);
             url2.generateMessageUrlInfo();
             lstUrls.append(std::move(url2));
         }
@@ -580,14 +580,14 @@ void MessageTest::shouldSerializeData()
         QList<Reaction> reacts;
         {
             Reaction a;
-            a.setUserNames({QStringLiteral("bla"), QStringLiteral("foo")});
-            a.setReactionName(QStringLiteral(":)"));
+            a.setUserNames({u"bla"_s, u"foo"_s});
+            a.setReactionName(u":)"_s);
             reacts.append(std::move(a));
         }
         {
             Reaction a;
-            a.setUserNames({QStringLiteral("bli"), QStringLiteral("aa")});
-            a.setReactionName(QStringLiteral(":foo:"));
+            a.setUserNames({u"bli"_s, u"aa"_s});
+            a.setReactionName(u":foo:"_s);
             reacts.append(std::move(a));
         }
 
@@ -597,18 +597,18 @@ void MessageTest::shouldSerializeData()
 
         // Message Translation
         MessageTranslations l;
-        l.setTranslatedString({{QStringLiteral("foo"), QStringLiteral("bla")}});
+        l.setTranslatedString({{u"foo"_s, u"bla"_s}});
         input.setMessageTranslation(l);
 
         // LocalTranslation
-        input.setLocalTranslation(QStringLiteral("message fr"));
+        input.setLocalTranslation(u"message fr"_s);
 
         // Mention
         QMap<QString, QByteArray> mentions;
-        mentions.insert(QStringLiteral("bla1"), "foo1"_ba);
-        mentions.insert(QStringLiteral("bla2"), "foo2"_ba);
-        mentions.insert(QStringLiteral("bla3"), "foo3"_ba);
-        mentions.insert(QStringLiteral("bla4"), "foo4"_ba);
+        mentions.insert(u"bla1"_s, "foo1"_ba);
+        mentions.insert(u"bla2"_s, "foo2"_ba);
+        mentions.insert(u"bla3"_s, "foo3"_ba);
+        mentions.insert(u"bla4"_s, "foo4"_ba);
         input.setMentions(mentions);
 
         // Channels
@@ -616,22 +616,22 @@ void MessageTest::shouldSerializeData()
         QList<Channels::ChannelInfo> lst;
         {
             Channels::ChannelInfo info;
-            info.fname = QStringLiteral("fnamechannel1");
-            info.name = QStringLiteral("channel1");
+            info.fname = u"fnamechannel1"_s;
+            info.name = u"channel1"_s;
             info.identifier = "foo-1"_ba;
             lst.append(std::move(info));
         }
         {
             Channels::ChannelInfo info;
-            info.fname = QStringLiteral("fnamechannel2");
-            info.name = QStringLiteral("channel2");
+            info.fname = u"fnamechannel2"_s;
+            info.name = u"channel2"_s;
             info.identifier = "foo-2"_ba;
             lst.append(std::move(info));
         }
         {
             Channels::ChannelInfo info;
-            info.fname = QStringLiteral("fnamechannel3");
-            info.name = QStringLiteral("channel3");
+            info.fname = u"fnamechannel3"_s;
+            info.name = u"channel3"_s;
             info.identifier = "foo-3"_ba;
             lst.append(std::move(info));
         }
@@ -646,7 +646,7 @@ void MessageTest::shouldSerializeData()
         // MessagePinned
         MessagePinned pinned;
         pinned.setPinned(true);
-        pinned.setPinnedBy(QStringLiteral("kla"));
+        pinned.setPinnedBy(u"kla"_s);
         input.setMessagePinned(pinned);
 
         // Blocks
@@ -654,15 +654,15 @@ void MessageTest::shouldSerializeData()
         QList<Block> blockInfos;
         {
             Block b;
-            b.setBlockId(QStringLiteral("block-id1"));
-            b.setAppId(QStringLiteral("appid-1"));
+            b.setBlockId(u"block-id1"_s);
+            b.setAppId(u"appid-1"_s);
             b.setBlockType(Block::BlockType::VideoConf);
             blockInfos.append(b);
         }
         {
             Block b;
-            b.setBlockId(QStringLiteral("block-id2"));
-            b.setAppId(QStringLiteral("appid-2"));
+            b.setBlockId(u"block-id2"_s);
+            b.setAppId(u"appid-2"_s);
             b.setBlockType(Block::BlockType::VideoConf);
             blockInfos.append(b);
         }
@@ -702,19 +702,19 @@ void MessageTest::shouldSerializeData()
 
         input.setMessageId("ff"_ba);
         input.setRoomId("room1"_ba);
-        input.setText(QStringLiteral("message1"));
+        input.setText(u"message1"_s);
         input.setTimeStamp(42);
-        input.setUsername(QStringLiteral("user1"));
+        input.setUsername(u"user1"_s);
         input.setUserId("userid1"_ba);
         input.setUpdatedAt(45);
         input.setEditedAt(89);
-        input.setEditedByUsername(QStringLiteral("editeduser1"));
-        input.setAlias(QStringLiteral("ali"));
-        input.setAvatar(QStringLiteral("avatar1"));
+        input.setEditedByUsername(u"editeduser1"_s);
+        input.setAlias(u"ali"_s);
+        input.setAvatar(u"avatar1"_s);
         input.setSystemMessageType(SystemMessageTypeUtil::MessageDeleted);
-        input.setLocalTranslation(QStringLiteral("Local !!!!"));
+        input.setLocalTranslation(u"Local !!!!"_s);
         input.setParseUrls(true);
-        input.setRole(QStringLiteral("leader"));
+        input.setRole(u"leader"_s);
         input.setMessageType(Message::MessageType::NormalText);
         // It will break as it's not supported yet
         input.setIsStarred(true);
@@ -731,23 +731,23 @@ void MessageTest::shouldSerializeData()
 void MessageTest::shouldParseJsonMessage_data()
 {
     QTest::addColumn<QString>("fileName");
-    QTest::newRow("empty") << QStringLiteral("empty");
-    QTest::newRow("standardmessage") << QStringLiteral("standardmessage");
-    QTest::newRow("attachmentimage") << QStringLiteral("attachmentimage");
-    QTest::newRow("attachment-author") << QStringLiteral("attachment-author");
-    QTest::newRow("message-url") << QStringLiteral("message-url");
-    QTest::newRow("message-url-meta-info") << QStringLiteral("message-url-meta-info");
-    QTest::newRow("message-reactions") << QStringLiteral("message-reactions");
-    QTest::newRow("animatedimage") << QStringLiteral("animatedimage");
-    QTest::newRow("emojimessage") << QStringLiteral("emojimessage");
-    QTest::newRow("attachmentaudio") << QStringLiteral("attachmentaudio");
-    QTest::newRow("attachmentimage-preview") << QStringLiteral("attachmentimage-preview");
-    QTest::newRow("message-attachment-link") << QStringLiteral("message-attachment-link");
+    QTest::newRow("empty") << u"empty"_s;
+    QTest::newRow("standardmessage") << u"standardmessage"_s;
+    QTest::newRow("attachmentimage") << u"attachmentimage"_s;
+    QTest::newRow("attachment-author") << u"attachment-author"_s;
+    QTest::newRow("message-url") << u"message-url"_s;
+    QTest::newRow("message-url-meta-info") << u"message-url-meta-info"_s;
+    QTest::newRow("message-reactions") << u"message-reactions"_s;
+    QTest::newRow("animatedimage") << u"animatedimage"_s;
+    QTest::newRow("emojimessage") << u"emojimessage"_s;
+    QTest::newRow("attachmentaudio") << u"attachmentaudio"_s;
+    QTest::newRow("attachmentimage-preview") << u"attachmentimage-preview"_s;
+    QTest::newRow("message-attachment-link") << u"message-attachment-link"_s;
     // TODO fix them
-    QTest::newRow("message-bug-435718") << QStringLiteral("message-bug-435718");
-    QTest::newRow("message-bug-435718-2") << QStringLiteral("message-bug-435718-2");
-    QTest::newRow("message-bug-435718-3") << QStringLiteral("message-bug-435718-3");
-    QTest::newRow("message-channel-mentions") << QStringLiteral("message-channel-mentions");
+    QTest::newRow("message-bug-435718") << u"message-bug-435718"_s;
+    QTest::newRow("message-bug-435718-2") << u"message-bug-435718-2"_s;
+    QTest::newRow("message-bug-435718-3") << u"message-bug-435718-3"_s;
+    QTest::newRow("message-channel-mentions") << u"message-channel-mentions"_s;
 }
 
 void MessageTest::shouldParseJsonMessage()
@@ -770,7 +770,7 @@ void MessageTest::shouldParseJsonMessage()
     const QJsonDocument docSerialized = QJsonDocument::fromJson(ba);
 
     const QByteArray jsonIndented = docSerialized.toJson(QJsonDocument::Indented);
-    AutoTestHelper::compareFile(QStringLiteral("/messages/"), jsonIndented, fileName);
+    AutoTestHelper::compareFile(u"/messages/"_s, jsonIndented, fileName);
 
     Message m = Message::deserialize(docSerialized.object());
     bool compareMessage = (r == m);
@@ -785,12 +785,11 @@ void MessageTest::shouldUpdateJsonMessage_data()
 {
     QTest::addColumn<QString>("fileNameinit");
     QTest::addColumn<QStringList>("fileNameupdate");
-    QTest::newRow("standardmessage") << QStringLiteral("standardmessage") << QStringList();
-    QTest::newRow("message1-init") << QStringLiteral("message1-init") << QStringList();
-    QTest::newRow("message1") << QStringLiteral("message1") << (QStringList() << QStringLiteral("message1-updated"));
-    QTest::newRow("message2") << QStringLiteral("message2")
-                              << (QStringList() << QStringLiteral("message2-updated") << QStringLiteral("message2-updated-stared"));
-    QTest::newRow("message3") << QStringLiteral("message3") << (QStringList() << QStringLiteral("message3-updated"));
+    QTest::newRow("standardmessage") << u"standardmessage"_s << QStringList();
+    QTest::newRow("message1-init") << u"message1-init"_s << QStringList();
+    QTest::newRow("message1") << u"message1"_s << (QStringList() << u"message1-updated"_s);
+    QTest::newRow("message2") << u"message2"_s << (QStringList() << u"message2-updated"_s << u"message2-updated-stared"_s);
+    QTest::newRow("message3") << u"message3"_s << (QStringList() << u"message3-updated"_s);
     // TODO add more !
 }
 
@@ -828,7 +827,7 @@ void MessageTest::shouldUpdateJsonMessage()
     const QJsonDocument docSerialized = QJsonDocument::fromJson(ba);
 
     const QByteArray jsonIndented = docSerialized.toJson(QJsonDocument::Indented);
-    AutoTestHelper::compareFile(QStringLiteral("/messages-updated/"), jsonIndented, fileNameinit);
+    AutoTestHelper::compareFile(u"/messages-updated/"_s, jsonIndented, fileNameinit);
 
     Message m = Message::deserialize(docSerialized.object());
     const bool compareMessage = (r == m);
