@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2024-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #include "messageurlstest.h"
 #include "messages/messageurls.h"
 #include <QTest>
-QTEST_MAIN(MessageUrlsTest)
+QTEST_GUILESS_MAIN(MessageUrlsTest)
 
 MessageUrlsTest::MessageUrlsTest(QObject *parent)
     : QObject{parent}
