@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "permissionstest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "permissions/permissions.h"
 #include "ruqola_autotest_helper.h"
 
@@ -27,7 +29,7 @@ void PermissionsTest::shouldLoadPermissions_data()
     QTest::addColumn<QString>("name");
     QTest::addColumn<int>("permissionsCount");
 
-    QTest::addRow("permissions1") << QStringLiteral("permissions1") << 3;
+    QTest::addRow("permissions1") << u"permissions1"_s << 3;
 }
 
 void PermissionsTest::shouldLoadPermissions()
