@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,7 +8,7 @@
 #include "videoconference/updatevideoconferencemessagejob.h"
 #include <QTest>
 
-QTEST_MAIN(UpdateVideoConferenceMessageJobTest)
+QTEST_GUILESS_MAIN(UpdateVideoConferenceMessageJobTest)
 
 UpdateVideoConferenceMessageJobTest::UpdateVideoConferenceMessageJobTest(QObject *parent)
     : QObject{parent}
