@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,7 +7,7 @@
 #include "videoconferencenotificationjobtest.h"
 #include "videoconference/videoconferencenotificationjob.h"
 #include <QTest>
-QTEST_MAIN(VideoConferenceNotificationJobTest)
+QTEST_GUILESS_MAIN(VideoConferenceNotificationJobTest)
 
 VideoConferenceNotificationJobTest::VideoConferenceNotificationJobTest(QObject *parent)
     : QObject{parent}
