@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -24,135 +24,135 @@ void CustomSoundsManager::initializeDefaultSounds()
         CustomSoundInfo info;
         info.setName(i18n("None"));
         info.setDefaultSound(true);
-        info.setIdentifier(QByteArrayLiteral("none"));
+        info.setIdentifier("none"_ba);
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setName(i18n("Default"));
         info.setDefaultSound(true);
-        info.setIdentifier(QByteArrayLiteral("default"));
+        info.setIdentifier("default"_ba);
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setDefaultSound(true);
-        info.setIdentifier(QByteArrayLiteral("chime"));
+        info.setIdentifier("chime"_ba);
         info.setName(i18n("Chime"));
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setDefaultSound(true);
-        info.setIdentifier(QByteArrayLiteral("door"));
+        info.setIdentifier("door"_ba);
         info.setName(i18n("Door"));
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setDefaultSound(true);
-        info.setIdentifier(QByteArrayLiteral("beep"));
+        info.setIdentifier("beep"_ba);
         info.setName(i18n("Beep"));
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setDefaultSound(true);
-        info.setIdentifier(QByteArrayLiteral("chelle"));
+        info.setIdentifier("chelle"_ba);
         info.setName(i18n("Chelle"));
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setDefaultSound(true);
-        info.setIdentifier(QByteArrayLiteral("ding"));
+        info.setIdentifier("ding"_ba);
         info.setName(i18n("Ding"));
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setDefaultSound(true);
-        info.setIdentifier(QByteArrayLiteral("droplet"));
-        info.setName(QStringLiteral("Droplet"));
+        info.setIdentifier("droplet"_ba);
+        info.setName(u"Droplet"_s);
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
         info.setDefaultSound(true);
-        info.setExtension(QStringLiteral("mp3"));
-        info.setIdentifier(QByteArrayLiteral("highbell"));
+        info.setExtension(u"mp3"_s);
+        info.setIdentifier("highbell"_ba);
         info.setName(i18n("Highbell"));
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
         info.setDefaultSound(true);
-        info.setExtension(QStringLiteral("mp3"));
-        info.setIdentifier(QByteArrayLiteral("seasons"));
+        info.setExtension(u"mp3"_s);
+        info.setIdentifier("seasons"_ba);
         info.setName(i18n("Seasons"));
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
         info.setDefaultSound(true);
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setName(i18n("Chime"));
-        info.setIdentifier(QByteArrayLiteral("chime"));
+        info.setIdentifier("chime"_ba);
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
         info.setDefaultSound(true);
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setName(i18n("Door"));
-        info.setIdentifier(QByteArrayLiteral("door"));
+        info.setIdentifier("door"_ba);
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
         info.setDefaultSound(true);
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setName(i18n("Telephone"));
-        info.setIdentifier(QByteArrayLiteral("telephone"));
+        info.setIdentifier("telephone"_ba);
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
         info.setDefaultSound(true);
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setName(i18n("Outbound Call Ringing"));
-        info.setIdentifier(QByteArrayLiteral("outbound-call-ringing"));
+        info.setIdentifier("outbound-call-ringing"_ba);
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
         info.setDefaultSound(true);
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setName(i18n("Call Ended"));
-        info.setIdentifier(QByteArrayLiteral("call-ended"));
+        info.setIdentifier("call-ended"_ba);
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
         info.setDefaultSound(true);
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setName(i18n("Dialtone"));
-        info.setIdentifier(QByteArrayLiteral("dialtone"));
+        info.setIdentifier("dialtone"_ba);
         listSounds.append(std::move(info));
     }
     {
         CustomSoundInfo info;
         info.setDefaultSound(true);
-        info.setExtension(QStringLiteral("mp3"));
+        info.setExtension(u"mp3"_s);
         info.setName(i18n("Ringtone"));
-        info.setIdentifier(QByteArrayLiteral("ringtone"));
+        info.setIdentifier("ringtone"_ba);
         listSounds.append(std::move(info));
     }
 
@@ -224,7 +224,7 @@ void CustomSoundsManager::updateCustomSounds(const QJsonArray &replyArray)
                     CustomSoundInfo sound;
                     sound.parseCustomSoundInfo(emojiData);
                     if (sound.isValid()) {
-                        mCustomSoundsInfo.append(sound);
+                        mCustomSoundsInfo.append(std::move(sound));
                         Q_EMIT customSoundUpdated(identifier);
                         Q_EMIT customSoundChanged();
                     }
