@@ -8,8 +8,9 @@
 
 #pragma once
 
-#include <QObject>
+class QObject;
 
+#include "authenticationmanager/authenticationmanagerbase.h"
 #include "libruqolacore_export.h"
 
 class DDPClient;
@@ -19,7 +20,7 @@ class DDPClient;
  * @brief Abstract class describing the interface for classes that may subscribe to DDP events
  *   and call DDP methods.
  */
-class LIBRUQOLACORE_EXPORT DDPManager : public QObject
+class LIBRUQOLACORE_EXPORT DDPManager : public AuthenticationManagerBase
 {
     Q_OBJECT
 
@@ -36,6 +37,5 @@ protected:
     DDPClient *mDdpClient = nullptr;
 
 private:
-    virtual void processMethodResponseImpl(int opId, const QJsonObject &response) = 0;
     virtual void processSubscriptionResultImpl(int subId, const QJsonObject &result) = 0;
 };
