@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #pragma once
-#include "libruqola_private_export.h"
+#include "libruqolacore_export.h"
 #include <QJsonObject>
 #include <QMap>
-class LIBRUQOLACORE_TESTS_EXPORT DownloadAppsLanguagesInfo
+class LIBRUQOLACORE_EXPORT DownloadAppsLanguagesInfo
 {
 public:
     DownloadAppsLanguagesInfo();
