@@ -8,16 +8,19 @@
 #include "libruqolacore_export.h"
 #include "localdatabasebase.h"
 class Room;
+class QSqlTableModel;
 class LIBRUQOLACORE_EXPORT LocalRoomsDatabase : public LocalDatabaseBase
 {
 public:
     LocalRoomsDatabase();
     ~LocalRoomsDatabase() override;
     void updateRoom(const QString &accountName, Room *room);
-    void deleteRoom(const QString &accountName, const QString &roomId);
+    void deleteRoom(const QString &accountName, const QByteArray &roomId);
 
     [[nodiscard]] QByteArray jsonRoom(const QString &accountName, const QString &roomId);
 
+    [[nodiscard]] std::unique_ptr<QSqlTableModel> createRoomsModel(const QString &accountName) const;
+
 protected:
     [[nodiscard]] QString schemaDataBase() const override;
 };
