@@ -7,7 +7,6 @@
 #include "messagecache.h"
 
 #include "connection.h"
-#include "misc/methodcalljob.h"
 #include "rocketchataccount.h"
 #include "ruqola_debug.h"
 
@@ -59,7 +58,7 @@ Message *MessageCache::messageForId(const QByteArray &messageId)
         auto job = new RocketChatRestApi::MethodCallJob(this);
 
         const RocketChatRestApi::MethodCallJob::MethodCallJobInfo info = generateMethodCallInfo(messageId);
-        job->setMethodCallJobInfo(std::move(info));
+        job->setMethodCallJobInfo(info);
         mMessageJobs.insert(messageId, job);
         connect(job, &RocketChatRestApi::MethodCallJob::methodCallDone, this, [this, messageId](const QJsonObject &replyObj) {
             slotGetSingleMessageDone(replyObj, messageId);
@@ -130,7 +129,7 @@ bool MessageCache::startJob(RocketChatRestApi::RestApiAbstractJob *job)
 RocketChatRestApi::MethodCallJob::MethodCallJobInfo MessageCache::generateMethodCallInfo(const QByteArray &messageId)
 {
     RocketChatRestApi::MethodCallJob::MethodCallJobInfo info;
-    info.methodName = QStringLiteral("getSingleMessage");
+    info.methodName = u"getSingleMessage"_s;
     const QJsonArray params{QString::fromLatin1(messageId)};
     info.messageObj = mRocketChatAccount->ddp()->generateJsonObject(info.methodName, params);
     info.anonymous = false;
