@@ -22,26 +22,26 @@ void Message::parseMessage(const QJsonObject &o, bool restApi, EmojiManager *emo
     mRoomId = o.value("rid"_L1).toString().toLatin1();
     mText = o.value("msg"_L1).toString();
     if (restApi) {
-        mUpdatedAt = Utils::parseIsoDate(QStringLiteral("_updatedAt"), o);
-        setEditedAt(Utils::parseIsoDate(QStringLiteral("editedAt"), o));
-        setTimeStamp(Utils::parseIsoDate(QStringLiteral("ts"), o));
-        if (o.contains(QStringLiteral("tlm"))) {
-            setThreadLastMessage(Utils::parseIsoDate(QStringLiteral("tlm"), o));
+        mUpdatedAt = Utils::parseIsoDate(u"_updatedAt"_s, o);
+        setEditedAt(Utils::parseIsoDate(u"editedAt"_s, o));
+        setTimeStamp(Utils::parseIsoDate(u"ts"_s, o));
+        if (o.contains(u"tlm"_s)) {
+            setThreadLastMessage(Utils::parseIsoDate(u"tlm"_s, o));
         }
-        if (o.contains(QStringLiteral("dlm"))) {
-            setDiscussionLastMessage(Utils::parseIsoDate(QStringLiteral("dlm"), o));
+        if (o.contains(u"dlm"_s)) {
+            setDiscussionLastMessage(Utils::parseIsoDate(u"dlm"_s, o));
         }
     } else {
-        setTimeStamp(Utils::parseDate(QStringLiteral("ts"), o));
-        mUpdatedAt = Utils::parseDate(QStringLiteral("_updatedAt"), o);
-        setEditedAt(Utils::parseDate(QStringLiteral("editedAt"), o));
+        setTimeStamp(Utils::parseDate(u"ts"_s, o));
+        mUpdatedAt = Utils::parseDate(u"_updatedAt"_s, o);
+        setEditedAt(Utils::parseDate(u"editedAt"_s, o));
         // Verify if a day we will use not restapi for it.
-        if (o.contains(QStringLiteral("tlm"))) {
-            setThreadLastMessage(Utils::parseDate(QStringLiteral("tlm"), o));
+        if (o.contains(u"tlm"_s)) {
+            setThreadLastMessage(Utils::parseDate(u"tlm"_s, o));
         }
         // Verify if a day we will use not restapi for it.
-        if (o.contains(QStringLiteral("dlm"))) {
-            setDiscussionLastMessage(Utils::parseDate(QStringLiteral("dlm"), o));
+        if (o.contains(u"dlm"_s)) {
+            setDiscussionLastMessage(Utils::parseDate(u"dlm"_s, o));
         }
     }
 
@@ -55,7 +55,7 @@ void Message::parseMessage(const QJsonObject &o, bool restApi, EmojiManager *emo
 
     setUnread(o.value("unread"_L1).toBool());
     setGroupable(o.value("groupable"_L1).toBool(/*true*/ false)); // Laurent, disable for the moment groupable
-    setParseUrls(o.value("parseUrls"_L1).toBool());
+    setParseUrls(o.value("parseUrls"_L1).toBool(false));
     mRole = o.value("role"_L1).toString();
     if (o.contains("tcount"_L1)) {
         setThreadCount(o.value("tcount"_L1).toInt());
@@ -99,7 +99,7 @@ void Message::parseMessage(const QJsonObject &o, bool restApi, EmojiManager *emo
             // qDebug() << " VIDEO " << o;
         } else if (type == "e2e"_L1) {
             mSystemMessageType = SystemMessageTypeUtil::systemMessageTypeFromString(type);
-            mMessageType = MessageType::System;
+            mMessageType = MessageType::EncryptedText;
             qDebug() << " encrypted message !!!!" << mText;
         } else {
             mSystemMessageType = SystemMessageTypeUtil::systemMessageTypeFromString(type);
@@ -205,6 +205,12 @@ bool Message::isAutoTranslated() const
     return false;
 }
 
+bool Message::isEncryptedMessage() const
+{
+    // TODO
+    return false;
+}
+
 bool Message::showTranslatedMessage() const
 {
     return messageStateValue(Translated);
@@ -516,11 +522,13 @@ void Message::setVideoConferenceInfo(const VideoConferenceInfo &info)
 
 void Message::parseMentions(const QJsonArray &mentions)
 {
-    mMentions.clear();
+    QMap<QString, QByteArray> m;
+
     for (int i = 0; i < mentions.size(); i++) {
         const QJsonObject mention = mentions.at(i).toObject();
-        mMentions.insert(mention.value("username"_L1).toString(), mention.value("_id"_L1).toString().toLatin1());
+        m.insert(mention.value("username"_L1).toString(), mention.value("_id"_L1).toString().toLatin1());
     }
+    setMentions(m);
 }
 
 void Message::parseMessageUrls(const QJsonArray &urls)
@@ -786,7 +794,7 @@ QString Message::systemMessageText() const
     case SystemMessageTypeUtil::SystemMessageType::RoomPrivacyChanged:
         return i18n("%2 changed room privacy to %1", mText, mUsername);
     case SystemMessageTypeUtil::SystemMessageType::JitsiCallStarted:
-        return QStringLiteral("<a href=\"ruqola:/jitsicall/\">") + i18n("Click to join to video") + QStringLiteral("</a>");
+        return u"<a href=\"ruqola:/jitsicall/\">"_s + i18n("Click to join to video") + u"</a>"_s;
     case SystemMessageTypeUtil::SystemMessageType::MessageDeleted:
         // TODO encrypted message
         return i18n("Message Deleted");
@@ -983,7 +991,7 @@ void Message::setTimeStamp(qint64 timeStamp)
 {
     if (mTimeStamp != timeStamp) {
         mTimeStamp = timeStamp;
-        mDisplayTime = QDateTime::fromMSecsSinceEpoch(mTimeStamp).time().toString(QStringLiteral("hh:mm"));
+        mDisplayTime = QDateTime::fromMSecsSinceEpoch(mTimeStamp).time().toString(u"hh:mm"_s);
     }
 }
 
@@ -1092,8 +1100,8 @@ Message Message::deserialize(const QJsonObject &o, EmojiManager *emojiManager)
     message.mEditedByUsername = o["editedByUsername"_L1].toString();
     message.mAlias = o["alias"_L1].toString();
     message.mAvatar = o["avatar"_L1].toString();
-    message.setGroupable(o["groupable"_L1].toBool());
-    message.setParseUrls(o["parseUrls"_L1].toBool());
+    message.setGroupable(o["groupable"_L1].toBool(false));
+    message.setParseUrls(o["parseUrls"_L1].toBool(false));
     message.setUnread(o["unread"_L1].toBool());
     message.mMessageStarred.setIsStarred(o["starred"_L1].toBool());
 
@@ -1144,7 +1152,7 @@ Message Message::deserialize(const QJsonObject &o, EmojiManager *emojiManager)
         const QJsonObject mention = mentionsArray.at(i).toObject();
         mentions.insert(mention.value("username"_L1).toString(), mention.value("_id"_L1).toString().toLatin1());
     }
-    message.setMentions(std::move(mentions));
+    message.setMentions(mentions);
 
     if (o.contains("channels"_L1)) {
         const QJsonArray channelsArray = o.value("channels"_L1).toArray();
@@ -1180,7 +1188,9 @@ QByteArray Message::serialize(const Message &message, bool toBinary)
 
     o["messageID"_L1] = QString::fromLatin1(message.mMessageId);
     o["roomID"_L1] = QString::fromLatin1(message.mRoomId);
-    o["message"_L1] = message.mText;
+    if (!message.mText.isEmpty()) {
+        o["message"_L1] = message.mText;
+    }
     o["timestamp"_L1] = message.mTimeStamp;
     o["username"_L1] = message.mUsername;
     if (!message.mName.isEmpty()) {
@@ -1204,8 +1214,12 @@ QByteArray Message::serialize(const Message &message, bool toBinary)
     if (!message.mAvatar.isEmpty()) {
         o["avatar"_L1] = message.mAvatar;
     }
-    o["groupable"_L1] = message.groupable();
-    o["parseUrls"_L1] = message.parseUrls();
+    if (message.groupable()) {
+        o["groupable"_L1] = true;
+    }
+    if (message.parseUrls()) {
+        o["parseUrls"_L1] = true;
+    }
     if (message.unread()) {
         o["unread"_L1] = true;
     }
@@ -1224,8 +1238,10 @@ QByteArray Message::serialize(const Message &message, bool toBinary)
         o["emoji"_L1] = message.mEmoji;
     }
 
-    if (const QString typeMessage = SystemMessageTypeUtil::systemMessageTypeStringFromEnum(message.mSystemMessageType); !typeMessage.isEmpty()) {
-        o["type"_L1] = typeMessage;
+    if (message.mSystemMessageType != SystemMessageTypeUtil::SystemMessageType::Unknown) {
+        if (const QString typeMessage = SystemMessageTypeUtil::systemMessageTypeStringFromEnum(message.mSystemMessageType); !typeMessage.isEmpty()) {
+            o["type"_L1] = typeMessage;
+        }
     }
     o["messageType"_L1] = QJsonValue::fromVariant(QVariant::fromValue<Message::MessageType>(message.mMessageType));
 
