@@ -8,11 +8,10 @@
 
 #include "ruqola_message_memory_debug.h"
 #include <QJsonArray>
-#include <QJsonObject>
 
 using namespace Qt::Literals::StringLiterals;
 Replies::Replies()
-    : QSharedData()
+
 {
     qCDebug(RUQOLA_MESSAGE_MEMORY_LOG) << " Replies created " << this;
 }
