@@ -21,8 +21,9 @@ void DirectoryTeamsModel::checkFullList()
 
 int DirectoryTeamsModel::rowCount(const QModelIndex &parent) const
 {
-    if (parent.isValid()) // flat model
+    if (parent.isValid()) { // flat model
         return 0;
+    }
     return mRoomsInfo.count();
 }
 
@@ -103,9 +104,8 @@ QVariant DirectoryTeamsModel::headerData(int section, Qt::Orientation orientatio
     return {};
 }
 
-int DirectoryTeamsModel::columnCount(const QModelIndex &parent) const
+int DirectoryTeamsModel::columnCount([[maybe_unused]] const QModelIndex &parent) const
 {
-    Q_UNUSED(parent)
     constexpr int val = static_cast<int>(DirectoryTeamsModel::LastColumn) + 1;
     return val;
 }
