@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -39,6 +39,19 @@ ListMessagesModel::ListMessageType ListMessagesFilterProxyModel::listMessageType
     return mModel->listMessageType();
 }
 
+ListMessagesFilterProxyModel::FilteringByType ListMessagesFilterProxyModel::getFilteringByType() const
+{
+    return mFilteringByType;
+}
+
+void ListMessagesFilterProxyModel::setFilteringByType(FilteringByType newFilteringByType)
+{
+    if (mFilteringByType != newFilteringByType) {
+        mFilteringByType = newFilteringByType;
+        invalidateFilter();
+    }
+}
+
 ListMessagesModel *ListMessagesFilterProxyModel::listMessageModel() const
 {
     return mModel;
@@ -64,4 +77,28 @@ void ListMessagesFilterProxyModel::clear()
     mModel->clear();
 }
 
+bool ListMessagesFilterProxyModel::filterAcceptsRow(int source_row, const QModelIndex &source_parent) const
+{
+    const QModelIndex sourceIndex = mModel->index(source_row, 0, source_parent);
+    switch (mFilteringByType) {
+    case FilteringByType::All:
+        break;
+    case FilteringByType::Unread: {
+        const bool unread = sourceIndex.data(ListMessagesModel::Unread).toBool();
+        if (!unread) {
+            return false;
+        }
+        break;
+    }
+    case FilteringByType::Following: {
+        const bool following = sourceIndex.data(ListMessagesModel::MessageReplies).toBool();
+        if (!following) {
+            return false;
+        }
+        break;
+    }
+    }
+    return QSortFilterProxyModel::filterAcceptsRow(source_row, source_parent);
+}
+
 #include "moc_listmessagesfilterproxymodel.cpp"
