@@ -16,8 +16,9 @@ NotificationDesktopSoundPreferenceModel::~NotificationDesktopSoundPreferenceMode
 
 int NotificationDesktopSoundPreferenceModel::rowCount(const QModelIndex &parent) const
 {
-    if (parent.isValid()) // flat model
+    if (parent.isValid()) { // flat model
         return 0;
+    }
 
     return mCustomSoundManager->customSoundsInfo().count();
 }
