@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,7 +16,9 @@ NotificationHistoryModel::~NotificationHistoryModel() = default;
 
 int NotificationHistoryModel::rowCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent)
+    if (parent.isValid()) { // flat model
+        return 0;
+    }
     return mNotificationInfo.count();
 }
 
