@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "servererrorinfohistorymodel.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include <KLocalizedString>
 
 ServerErrorInfoHistoryModel::ServerErrorInfoHistoryModel(QObject *parent)
@@ -16,7 +18,9 @@ ServerErrorInfoHistoryModel::~ServerErrorInfoHistoryModel() = default;
 
 int ServerErrorInfoHistoryModel::rowCount(const QModelIndex &parent) const
 {
-    Q_UNUSED(parent)
+    if (parent.isValid()) { // flat model
+        return 0;
+    }
     return mServerErrorInfo.count();
 }
 
