@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -111,10 +111,10 @@ RetentionInfo RetentionInfo::deserialize(const QJsonObject &obj)
 
 QDebug operator<<(QDebug d, RetentionInfo t)
 {
-    d << "Enabled " << t.enabled();
-    d << "overrideGlobal " << t.overrideGlobal();
-    d << "excludePinned " << t.excludePinned();
-    d << "filesOnly " << t.filesOnly();
-    d << "maxAge " << t.maxAge();
+    d.space() << "Enabled" << t.enabled();
+    d.space() << "overrideGlobal" << t.overrideGlobal();
+    d.space() << "excludePinned" << t.excludePinned();
+    d.space() << "filesOnly" << t.filesOnly();
+    d.space() << "maxAge" << t.maxAge();
     return d;
 }
