@@ -91,7 +91,7 @@ class LIBRUQOLACORE_EXPORT RocketChatAccount : public QObject
 {
     Q_OBJECT
 public:
-    explicit RocketChatAccount(const QString &accountName = QString(), QObject *parent = nullptr);
+    explicit RocketChatAccount(const QString &accountName = QString(), bool migrateDatabase = false, QObject *parent = nullptr);
     ~RocketChatAccount() override;
 
     enum class ChannelTypeInfo : uint8_t {
@@ -189,7 +189,7 @@ public:
     void loadMoreFileAttachments(const QByteArray &roomId, Room::RoomType channelType);
     void loadMoreDiscussions(const QByteArray &roomId);
     void loadThreadMessagesHistory(const QByteArray &threadMessageId);
-    void loadMoreUsersInRoom(const QByteArray &roomId, Room::RoomType channelType);
+    void loadMoreUsersInRoom(const QByteArray &roomId, Room::RoomType channelType, const QString &filter);
     void loadMoreListMessages(const QByteArray &roomId);
 
     [[nodiscard]] MessagesModel *messageModelForRoom(const QByteArray &roomID);
@@ -361,8 +361,8 @@ public:
     [[nodiscard]] VideoConferenceMessageInfoManager *videoConferenceMessageInfoManager() const;
 
     [[nodiscard]] QUrl faviconLogoUrlFromLocalCache(const QString &url);
-    void addMessageToDataBase(const QString &roomName, const Message &message);
-    void deleteMessageFromDatabase(const QString &roomName, const QByteArray &messageId);
+    void addMessageToDataBase(const QByteArray &roomId, const Message &message);
+    void deleteMessageFromDatabase(const QByteArray &roomId, const QByteArray &messageId);
     void loadAccountSettings();
 
     [[nodiscard]] QList<AuthenticationInfo> authenticationMethodInfos() const;
@@ -424,6 +424,10 @@ public:
 
     [[nodiscard]] bool isFileDeletable(const QByteArray &roomId, const QByteArray &fileUserId, qint64 uploadedAt) const;
 
+    void deleteRoomFromDatabase(const QByteArray &roomId);
+    void addRoomToDataBase(Room *r);
+    void updateRoomInDatabase(const QByteArray &roomId);
+    void addMessagesToDataBase(const QByteArray &roomId, const QList<Message> &messages);
 Q_SIGNALS:
     void showUiInteraction(const QJsonArray &uiInteraction);
     void roomRemoved(const QByteArray &roomId);
@@ -499,11 +503,11 @@ private:
     LIBRUQOLACORE_NO_EXPORT void getPinnedMessages(const QByteArray &roomId);
     LIBRUQOLACORE_NO_EXPORT void getStarredMessages(const QByteArray &roomId);
     LIBRUQOLACORE_NO_EXPORT void getMentionsMessages(const QByteArray &roomId);
-    LIBRUQOLACORE_NO_EXPORT void parseUsersForRooms(const QJsonObject &obj, const QByteArray &channelInfoIdentifier);
+    LIBRUQOLACORE_NO_EXPORT void parseUsersForRooms(const QJsonObject &obj, const QByteArray &channelInfoIdentifier, const QString &filter);
 
     LIBRUQOLACORE_NO_EXPORT void threadsInRoom(const QByteArray &roomId, bool onlyUnread);
 
-    LIBRUQOLACORE_NO_EXPORT void membersInRoom(const QByteArray &roomId, Room::RoomType channelType);
+    LIBRUQOLACORE_NO_EXPORT void membersInRoom(const QByteArray &roomId, Room::RoomType channelType, const QString &filter);
 
     LIBRUQOLACORE_NO_EXPORT void slotInformTypingStatus(const QByteArray &room, bool typing);
 
@@ -554,7 +558,7 @@ private:
     LIBRUQOLACORE_NO_EXPORT void slotUsersSetPreferencesDone(const QJsonObject &replyObject);
     LIBRUQOLACORE_NO_EXPORT void slotUpdateCustomUserStatus();
     LIBRUQOLACORE_NO_EXPORT void updateCustomEmojiList(bool fetchListCustom);
-    LIBRUQOLACORE_NO_EXPORT void slotLoadRoles();
+    LIBRUQOLACORE_NO_EXPORT void loadRoles();
     LIBRUQOLACORE_NO_EXPORT void slotAwayStatusChanged(bool away);
     LIBRUQOLACORE_NO_EXPORT void slotJobFailed(const QString &str);
     LIBRUQOLACORE_NO_EXPORT void checkLicenses();
