@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "role.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "ruqola_debug.h"
 
 #include <QJsonArray>
 #include <QJsonObject>
 
+using namespace Qt::Literals::StringLiterals;
 Role::Role() = default;
 
 QByteArray Role::userId() const
@@ -107,10 +107,10 @@ void Role::parseRole(const QJsonObject &obj)
 
 QDebug operator<<(QDebug d, const Role &t)
 {
-    d << "UserId: " << t.userId();
-    d << "IsLeader: " << t.isLeader();
-    d << "IsOwner: " << t.isOwner();
-    d << "IsModerator: " << t.isModerator();
-    d << "UserName: " << t.userName();
+    d.space() << "UserId:" << t.userId();
+    d.space() << "IsLeader:" << t.isLeader();
+    d.space() << "IsOwner:" << t.isOwner();
+    d.space() << "IsModerator:" << t.isModerator();
+    d.space() << "UserName:" << t.userName();
     return d;
 }
