@@ -7,6 +7,7 @@
  */
 
 #include "ruqola.h"
+
 #include "customemojiiconmanager.h"
 #include "managerdatapaths.h"
 #include "rocketchataccount.h"
@@ -17,15 +18,22 @@
 #include "textautocorrectioncore/textautocorrectionsettings.h"
 #include <TextAutoCorrectionCore/AutoCorrection>
 #endif
-
+#if HAVE_TEXT_AUTOGENERATE_TEXT
+#include <TextAutoGenerateText/TextAutoGenerateManager>
+#endif
 static Ruqola *s_self = nullptr;
 
+using namespace Qt::Literals::StringLiterals;
 Ruqola::Ruqola(QObject *parent)
     : QObject(parent)
 #if HAVE_TEXT_AUTOCORRECTION_WIDGETS
     , mAutoCorrection(new TextAutoCorrectionCore::AutoCorrection())
+#endif
+#if HAVE_TEXT_AUTOGENERATE_TEXT
+    , mManager(new TextAutoGenerateText::TextAutoGenerateManager(this))
 #endif
     , mCustomEmojiIconManager(new CustomEmojiIconManager(this))
+
 {
     mDebug = !qEnvironmentVariableIsEmpty("RUQOLA_DEBUGGING");
     // Initialize paths
@@ -98,6 +106,12 @@ void Ruqola::setParentWidget(QWidget *newParentWidget)
 {
     mParentWidget = newParentWidget;
 }
+#if HAVE_TEXT_AUTOGENERATE_TEXT
+TextAutoGenerateText::TextAutoGenerateManager *Ruqola::textAutoGenerateManager() const
+{
+    return mManager;
+}
+#endif
 
 void Ruqola::setCurrentAccount(const QString &accountName)
 {
