@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -54,8 +54,8 @@ void TeamCompleter::setTeamId(const QByteArray &identifier)
 
 QDebug operator<<(QDebug d, const TeamCompleter &t)
 {
-    d << "Name " << t.name();
-    d << "Fname : " << t.fname();
-    d << "identifier: " << t.teamId();
+    d.space() << "Name" << t.name();
+    d.space() << "Fname:" << t.fname();
+    d.space() << "identifier:" << t.teamId();
     return d;
 }
