@@ -7,6 +7,7 @@
 #include "uploadfilemanager.h"
 #include "connection.h"
 #include "rocketchataccount.h"
+#include "rooms/roomsmediaconfirmjob.h"
 #include "ruqola_debug.h"
 
 #include <QFile>
@@ -43,6 +44,7 @@ int UploadFileManager::addUpload(const RocketChatRestApi::UploadFileJob::UploadF
         }
         mUploadMap.remove(jobIdentifier);
     });
+    connect(job, &RocketChatRestApi::UploadFileJob::confirmMediaRequested, this, &UploadFileManager::confirmMedia);
     if (!job->start()) {
         qCWarning(RUQOLA_LOG) << "Impossible to start UploadFileJob job";
         return -1;
@@ -52,6 +54,21 @@ int UploadFileManager::addUpload(const RocketChatRestApi::UploadFileJob::UploadF
     }
 }
 
+void UploadFileManager::confirmMedia(const RocketChatRestApi::UploadFileJob::ConfirmMediaInfo &info)
+{
+    const auto job = new RocketChatRestApi::RoomsMediaConfirmJob(this);
+    job->setFileId(info.fileId);
+    job->setRoomId(info.roomId);
+    job->setDescription(info.description);
+    mRocketChatAccount->restApi()->initializeRestApiJob(job);
+    connect(job, &RocketChatRestApi::RoomsMediaConfirmJob::roomsMediaConfirmDone, this, []() {
+        qDebug() << " media confirm ********";
+    });
+    if (!job->start()) {
+        qCWarning(RUQOLA_LOG) << "Impossible to start RoomsMediaConfirmJob job";
+    }
+}
+
 void UploadFileManager::removeFile(const RocketChatRestApi::UploadFileJob::UploadFileInfo &info)
 {
     if (info.deleteTemporaryFile) {
