@@ -5,6 +5,9 @@
 */
 
 #include "grabscreenplugintool.h"
+using namespace Qt::Literals::StringLiterals;
+
+#include "grabscreenplugintoolconfiguredialog.h"
 #include "grabscreenplugintoolinterface.h"
 #include "utils.h"
 #include <KLocalizedString>
@@ -22,7 +25,7 @@ GrabScreenPluginTool::~GrabScreenPluginTool() = default;
 
 bool GrabScreenPluginTool::toolFound() const
 {
-    return Utils::executableFound(QStringLiteral("spectacle"));
+    return Utils::executableFound(u"spectacle"_s);
 }
 
 PluginTool::ToolType GrabScreenPluginTool::toolType() const
@@ -32,7 +35,7 @@ PluginTool::ToolType GrabScreenPluginTool::toolType() const
 
 QString GrabScreenPluginTool::iconName() const
 {
-    return QStringLiteral("transform-crop");
+    return u"transform-crop"_s;
 }
 
 QString GrabScreenPluginTool::toolTip() const
@@ -42,13 +45,35 @@ QString GrabScreenPluginTool::toolTip() const
 
 QString GrabScreenPluginTool::description() const
 {
-    return {};
+    return i18n("This tool allows to create screenshot.");
 }
 
 PluginToolInterface *GrabScreenPluginTool::createInterface(QObject *parent)
 {
     return new GrabScreenPluginToolInterface(parent);
 }
+
+int GrabScreenPluginTool::order() const
+{
+    return 20;
+}
+
+bool GrabScreenPluginTool::hasMenu() const
+{
+    return false;
+}
+
+bool GrabScreenPluginTool::hasConfigureDialog() const
+{
+    return true;
+}
+
+void GrabScreenPluginTool::showConfigureDialog(QWidget *parent) const
+{
+    GrabScreenPluginToolConfigureDialog d(parent);
+    d.exec();
+    // TODO
+}
 #include "grabscreenplugintool.moc"
 
 #include "moc_grabscreenplugintool.cpp"
