@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -35,11 +35,11 @@ void User2FADisableEmailJob::onPostRequestResponse(const QString &replyErrorStri
 {
     const QJsonObject replyObject = replyJson.object();
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("User2FADisableEmailJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("User2FADisableEmailJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT disableEmailDone();
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("User2FADisableEmailJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("User2FADisableEmailJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
@@ -48,14 +48,6 @@ bool User2FADisableEmailJob::requireHttpAuthentication() const
     return true;
 }
 
-bool User2FADisableEmailJob::canStart() const
-{
-    if (!RestApiAbstractJob::canStart()) {
-        return false;
-    }
-    return true;
-}
-
 QNetworkRequest User2FADisableEmailJob::request() const
 {
     const QUrl url = mRestApiMethod->generateUrl(RestApiUtil::RestApiUrlType::Users2FADisableEmail);
@@ -67,7 +59,7 @@ QNetworkRequest User2FADisableEmailJob::request() const
 
 QJsonDocument User2FADisableEmailJob::json() const
 {
-    QJsonObject jsonObj;
+    const QJsonObject jsonObj;
     const QJsonDocument postData = QJsonDocument(jsonObj);
     return postData;
 }
