@@ -5,12 +5,13 @@
 */
 
 #include "addusertorolejobtest.h"
-using namespace Qt::Literals::StringLiterals;
+#include "restapimethod.h"
 
 #include "role/addusertorolejob.h"
 #include "ruqola_restapi_helper.h"
 #include <QJsonDocument>
 
+using namespace Qt::Literals::StringLiterals;
 QTEST_GUILESS_MAIN(AddUserToRoleJobTest)
 using namespace RocketChatRestApi;
 AddUserToRoleJobTest::AddUserToRoleJobTest(QObject *parent)
@@ -25,6 +26,9 @@ void AddUserToRoleJobTest::shouldHaveDefaultValue()
     QVERIFY(job.requireHttpAuthentication());
     QVERIFY(!job.hasQueryParameterSupport());
     QVERIFY(job.username().isEmpty());
+    QVERIFY(job.roleId().isEmpty());
+    QVERIFY(job.roleName().isEmpty());
+    QVERIFY(!job.useRC80());
 }
 
 void AddUserToRoleJobTest::shouldGenerateRequest()
@@ -38,18 +42,35 @@ void AddUserToRoleJobTest::shouldGenerateRequest()
 
 void AddUserToRoleJobTest::shouldGenerateJson()
 {
-    AddUserToRoleJob job;
+    {
+        AddUserToRoleJob job;
+        // Before RC 8.0.0
+        job.setUseRC80(false);
 
-    const QString username = u"foo1"_s;
-    job.setUsername(username);
-    const QString rolename = u"role1"_s;
-    job.setRoleName(rolename);
-    QCOMPARE(job.json().toJson(QJsonDocument::Compact), QStringLiteral(R"({"roleName":"%1","username":"%2"})").arg(rolename, username).toLatin1());
+        const QString username = u"foo1"_s;
+        job.setUsername(username);
+        const QString rolename = u"role1"_s;
+        job.setRoleName(rolename);
+        QCOMPARE(job.json().toJson(QJsonDocument::Compact), QStringLiteral(R"({"roleName":"%1","username":"%2"})").arg(rolename, username).toLatin1());
+    }
+    {
+        AddUserToRoleJob job;
+        job.setUseRC80(true);
+
+        const QString username = u"foo1"_s;
+        job.setUsername(username);
+        const QString rolename = u"role1"_s;
+        job.setRoleName(rolename);
+        const QString roleId = u"roleId1"_s;
+        job.setRoleId(roleId);
+        QCOMPARE(job.json().toJson(QJsonDocument::Compact), QStringLiteral(R"({"roleId":"%1","username":"%2"})").arg(roleId, username).toLatin1());
+    }
 }
 
 void AddUserToRoleJobTest::shouldNotStarting()
 {
     AddUserToRoleJob job;
+    job.setUseRC80(false);
 
     RestApiMethod method;
     method.setServerUrl(u"http://www.kde.org"_s);
@@ -71,6 +92,13 @@ void AddUserToRoleJobTest::shouldNotStarting()
     const QString rolename = u"role1"_s;
     job.setRoleName(rolename);
     QVERIFY(job.canStart());
+
+    job.setUseRC80(true);
+    QVERIFY(!job.canStart());
+
+    const QString roleId = u"roleId1"_s;
+    job.setRoleId(roleId);
+    QVERIFY(job.canStart());
 }
 
 #include "moc_addusertorolejobtest.cpp"
