@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "markroomasreadjobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "ruqola_restapi_helper.h"
 #include "subscriptions/markroomasreadjob.h"
 #include <QJsonDocument>
@@ -30,14 +32,14 @@ void MarkRoomAsReadJobTest::shouldGenerateRequest()
     MarkRoomAsReadJob job;
     QNetworkRequest request = QNetworkRequest(QUrl());
     verifyAuthentication(&job, request);
-    QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/subscriptions.read")));
-    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), QStringLiteral("application/json"));
+    QCOMPARE(request.url(), QUrl(u"http://www.kde.org/api/v1/subscriptions.read"_s));
+    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), u"application/json"_s);
 }
 
 void MarkRoomAsReadJobTest::shouldGenerateJson()
 {
     MarkRoomAsReadJob job;
-    const QByteArray roomId = QByteArrayLiteral("foo1");
+    const QByteArray roomId = "foo1"_ba;
     job.setRoomId(roomId);
     QCOMPARE(job.json().toJson(QJsonDocument::Compact), QStringLiteral(R"({"rid":"%1"})").arg(QLatin1StringView(roomId)).toLatin1());
 }
@@ -47,19 +49,19 @@ void MarkRoomAsReadJobTest::shouldNotStarting()
     MarkRoomAsReadJob job;
 
     RestApiMethod method;
-    method.setServerUrl(QStringLiteral("http://www.kde.org"));
+    method.setServerUrl(u"http://www.kde.org"_s);
     job.setRestApiMethod(&method);
 
     QNetworkAccessManager mNetworkAccessManager;
     job.setNetworkAccessManager(&mNetworkAccessManager);
     QVERIFY(!job.canStart());
-    const QString auth = QStringLiteral("foo");
-    const QString userId = QStringLiteral("foo");
+    const QString auth = u"foo"_s;
+    const QString userId = u"foo"_s;
     job.setAuthToken(auth);
     QVERIFY(!job.canStart());
     job.setUserId(userId);
     QVERIFY(!job.canStart());
-    const QByteArray roomId = QByteArrayLiteral("foo1");
+    const QByteArray roomId = "foo1"_ba;
     job.setRoomId(roomId);
     QVERIFY(job.canStart());
 }
