@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "moderationreportsjobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "moderation/moderationreportsjob.h"
 #include "restapimethod.h"
 #include "ruqola_restapi_helper.h"
@@ -28,9 +30,9 @@ void ModerationReportsJobTest::shouldGenerateRequest()
 {
     ModerationReportsJob job;
     QNetworkRequest request = QNetworkRequest(QUrl());
-    job.setMessageId(QByteArrayLiteral("foo"));
+    job.setMessageId("foo"_ba);
     verifyAuthentication(&job, request);
-    QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/moderation.reports?msgId=foo")));
+    QCOMPARE(request.url(), QUrl(u"http://www.kde.org/api/v1/moderation.reports?msgId=foo"_s));
 }
 
 #include "moc_moderationreportsjobtest.cpp"
