@@ -5,6 +5,8 @@
 */
 
 #include "permissionupdatejobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "permissions/permissionupdatejob.h"
 #include "ruqola_restapi_helper.h"
 #include <QJsonDocument>
@@ -29,16 +31,16 @@ void PermissionUpdateJobTest::shouldGenerateRequest()
     PermissionUpdateJob job;
     QNetworkRequest request = QNetworkRequest(QUrl());
     verifyAuthentication(&job, request);
-    QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/permissions.update")));
-    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), QStringLiteral("application/json"));
+    QCOMPARE(request.url(), QUrl(u"http://www.kde.org/api/v1/permissions.update"_s));
+    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), u"application/json"_s);
 }
 
 void PermissionUpdateJobTest::shouldGenerateJson()
 {
     PermissionUpdateJob job;
     QMap<QString, QStringList> lst;
-    lst.insert(QStringLiteral("bla"), {QStringLiteral("user"), QStringLiteral("admin")});
-    lst.insert(QStringLiteral("team"), {QStringLiteral("user"), QStringLiteral("admin"), QStringLiteral("owner")});
+    lst.insert(u"bla"_s, {u"user"_s, u"admin"_s});
+    lst.insert(u"team"_s, {u"user"_s, u"admin"_s, u"owner"_s});
     job.setPermissions(lst);
 
     QCOMPARE(job.json().toJson(QJsonDocument::Compact),
@@ -50,21 +52,21 @@ void PermissionUpdateJobTest::shouldNotStarting()
     PermissionUpdateJob job;
 
     RestApiMethod method;
-    method.setServerUrl(QStringLiteral("http://www.kde.org"));
+    method.setServerUrl(u"http://www.kde.org"_s);
     job.setRestApiMethod(&method);
 
     QNetworkAccessManager mNetworkAccessManager;
     job.setNetworkAccessManager(&mNetworkAccessManager);
     QVERIFY(!job.canStart());
-    const QString auth = QStringLiteral("foo");
-    const QString userId = QStringLiteral("foo");
+    const QString auth = u"foo"_s;
+    const QString userId = u"foo"_s;
     job.setAuthToken(auth);
     QVERIFY(!job.canStart());
     job.setUserId(userId);
     QVERIFY(!job.canStart());
     QMap<QString, QStringList> lst;
-    lst.insert(QStringLiteral("bla"), {QStringLiteral("user"), QStringLiteral("admin")});
-    lst.insert(QStringLiteral("team"), {QStringLiteral("user"), QStringLiteral("admin"), QStringLiteral("owner")});
+    lst.insert(u"bla"_s, {u"user"_s, u"admin"_s});
+    lst.insert(u"team"_s, {u"user"_s, u"admin"_s, u"owner"_s});
     job.setPermissions(lst);
     QVERIFY(job.canStart());
 }
