@@ -5,6 +5,8 @@
 */
 
 #include "resetowne2ekeyjobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "e2e/resetowne2ekeyjob.h"
 #include "ruqola_restapi_helper.h"
 #include <QJsonDocument>
@@ -28,8 +30,8 @@ void ResetOwnE2eKeyJobTest::shouldGenerateRequest()
     ResetOwnE2eKeyJob job;
     QNetworkRequest request = QNetworkRequest(QUrl());
     verifyAuthentication(&job, request);
-    QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/e2e.resetOwnE2EKey")));
-    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), QStringLiteral("application/json"));
+    QCOMPARE(request.url(), QUrl(u"http://www.kde.org/api/v1/e2e.resetOwnE2EKey"_s));
+    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), u"application/json"_s);
 }
 
 void ResetOwnE2eKeyJobTest::shouldGenerateJson()
@@ -44,14 +46,14 @@ void ResetOwnE2eKeyJobTest::shouldNotStarting()
     ResetOwnE2eKeyJob job;
 
     RestApiMethod method;
-    method.setServerUrl(QStringLiteral("http://www.kde.org"));
+    method.setServerUrl(u"http://www.kde.org"_s);
     job.setRestApiMethod(&method);
 
     QNetworkAccessManager mNetworkAccessManager;
     job.setNetworkAccessManager(&mNetworkAccessManager);
     QVERIFY(!job.canStart());
-    const QString auth = QStringLiteral("foo");
-    const QString userId = QStringLiteral("foo");
+    const QString auth = u"foo"_s;
+    const QString userId = u"foo"_s;
     job.setAuthToken(auth);
     QVERIFY(!job.canStart());
     job.setUserId(userId);
