@@ -5,6 +5,8 @@
 */
 
 #include "restapiutiltest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "restapiutil.h"
 #include <QTest>
 
@@ -19,9 +21,9 @@ void RestApiUtilTest::shouldAdaptUrl_data()
     QTest::addColumn<QString>("input");
     QTest::addColumn<QString>("output");
     QTest::newRow("empty") << QString() << QString();
-    QTest::newRow("withoutscheme") << QStringLiteral("foo.kde.org") << QStringLiteral("https://foo.kde.org");
-    QTest::newRow("withhttps") << QStringLiteral("https://foo.kde.org") << QStringLiteral("https://foo.kde.org");
-    QTest::newRow("withhttp") << QStringLiteral("http://foo.kde.org") << QStringLiteral("http://foo.kde.org");
+    QTest::newRow("withoutscheme") << u"foo.kde.org"_s << u"https://foo.kde.org"_s;
+    QTest::newRow("withhttps") << u"https://foo.kde.org"_s << u"https://foo.kde.org"_s;
+    QTest::newRow("withhttp") << u"http://foo.kde.org"_s << u"http://foo.kde.org"_s;
 }
 
 void RestApiUtilTest::shouldAdaptUrl()
@@ -33,9 +35,9 @@ void RestApiUtilTest::shouldAdaptUrl()
 
 void RestApiUtilTest::shouldConvertRestApiUrlExtensionType()
 {
-    QCOMPARE(RestApiUtil::restApiUrlExtensionType(RestApiUtil::RestApiUrlExtensionType::V1), QStringLiteral("/api/v1/"));
-    QCOMPARE(RestApiUtil::restApiUrlExtensionType(RestApiUtil::RestApiUrlExtensionType::Apps), QStringLiteral("/api/apps/"));
-    QCOMPARE(RestApiUtil::restApiUrlExtensionType(RestApiUtil::RestApiUrlExtensionType::NoExtension), QStringLiteral("/api/"));
+    QCOMPARE(RestApiUtil::restApiUrlExtensionType(RestApiUtil::RestApiUrlExtensionType::V1), u"/api/v1/"_s);
+    QCOMPARE(RestApiUtil::restApiUrlExtensionType(RestApiUtil::RestApiUrlExtensionType::Apps), u"/api/apps/"_s);
+    QCOMPARE(RestApiUtil::restApiUrlExtensionType(RestApiUtil::RestApiUrlExtensionType::NoExtension), u"/api/"_s);
 }
 
 #include "moc_restapiutiltest.cpp"
