@@ -5,6 +5,8 @@
 */
 
 #include "user2fasendemailcodejobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "2fa/user2fasendemailcodejob.h"
 #include "ruqola_restapi_helper.h"
 #include <QJsonDocument>
@@ -28,14 +30,14 @@ void User2FASendEmailCodeJobTest::shouldGenerateRequest()
     User2FASendEmailCodeJob job;
     QNetworkRequest request = QNetworkRequest(QUrl());
     verifyAuthentication(&job, request);
-    QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/users.2fa.sendEmailCode")));
-    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), QStringLiteral("application/json"));
+    QCOMPARE(request.url(), QUrl(u"http://www.kde.org/api/v1/users.2fa.sendEmailCode"_s));
+    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), u"application/json"_s);
 }
 
 void User2FASendEmailCodeJobTest::shouldGenerateJson()
 {
     User2FASendEmailCodeJob job;
-    const QString emails = QStringLiteral("emails");
+    const QString emails = u"emails"_s;
     job.setUsernameOrEmail(emails);
     QCOMPARE(job.json().toJson(QJsonDocument::Compact), QStringLiteral(R"({"emailOrUsername":"%1"})").arg(emails).toLatin1());
 }
@@ -45,19 +47,19 @@ void User2FASendEmailCodeJobTest::shouldNotStarting()
     User2FASendEmailCodeJob job;
 
     RestApiMethod method;
-    method.setServerUrl(QStringLiteral("http://www.kde.org"));
+    method.setServerUrl(u"http://www.kde.org"_s);
     job.setRestApiMethod(&method);
 
     QNetworkAccessManager mNetworkAccessManager;
     job.setNetworkAccessManager(&mNetworkAccessManager);
     QVERIFY(!job.canStart());
-    const QString auth = QStringLiteral("foo");
-    const QString userId = QStringLiteral("foo");
+    const QString auth = u"foo"_s;
+    const QString userId = u"foo"_s;
     job.setAuthToken(auth);
     QVERIFY(!job.canStart());
     job.setUserId(userId);
     QVERIFY(!job.canStart());
-    job.setUsernameOrEmail(QStringLiteral("emails"));
+    job.setUsernameOrEmail(u"emails"_s);
     QVERIFY(job.canStart());
 }
 
