@@ -5,6 +5,8 @@
 */
 
 #include "userslogoutotherclientsjobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "restapimethod.h"
 #include "users/userslogoutotherclientsjob.h"
 #include <QJsonDocument>
@@ -31,10 +33,10 @@ void UsersLogoutOtherClientsJobTest::shouldGenerateRequest()
 {
     UsersLogoutOtherClientsJob job;
     RestApiMethod method;
-    method.setServerUrl(QStringLiteral("http://www.kde.org"));
+    method.setServerUrl(u"http://www.kde.org"_s);
     job.setRestApiMethod(&method);
     const QNetworkRequest request = job.request();
-    QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/users.logoutOtherClients")));
+    QCOMPARE(request.url(), QUrl(u"http://www.kde.org/api/v1/users.logoutOtherClients"_s));
 }
 
 void UsersLogoutOtherClientsJobTest::shouldGenerateJson()
@@ -48,14 +50,14 @@ void UsersLogoutOtherClientsJobTest::shouldNotStarting()
     UsersLogoutOtherClientsJob job;
 
     RestApiMethod method;
-    method.setServerUrl(QStringLiteral("http://www.kde.org"));
+    method.setServerUrl(u"http://www.kde.org"_s);
     job.setRestApiMethod(&method);
 
     QNetworkAccessManager mNetworkAccessManager;
     job.setNetworkAccessManager(&mNetworkAccessManager);
     QVERIFY(!job.canStart());
-    const QString auth = QStringLiteral("foo");
-    const QString userId = QStringLiteral("foo");
+    const QString auth = u"foo"_s;
+    const QString userId = u"foo"_s;
     job.setAuthToken(auth);
     QVERIFY(!job.canStart());
     job.setUserId(userId);
