@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "userssetpreferencesjobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "ruqola_restapi_helper.h"
 #include "users/userssetpreferencesjob.h"
 #include <QJsonDocument>
@@ -29,8 +31,8 @@ void UsersSetPreferencesJobTest::shouldGenerateRequest()
     UsersSetPreferencesJob job;
     QNetworkRequest request = QNetworkRequest(QUrl());
     verifyAuthentication(&job, request);
-    QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/users.setPreferences")));
-    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), QStringLiteral("application/json"));
+    QCOMPARE(request.url(), QUrl(u"http://www.kde.org/api/v1/users.setPreferences"_s));
+    QCOMPARE(request.header(QNetworkRequest::ContentTypeHeader).toString(), u"application/json"_s);
 }
 
 void UsersSetPreferencesJobTest::shouldGenerateJson()
@@ -38,12 +40,12 @@ void UsersSetPreferencesJobTest::shouldGenerateJson()
     {
         UsersSetPreferencesJob job;
         UsersSetPreferencesJob::UsersSetPreferencesInfo info;
-        const QString desktopNotifications = QStringLiteral("Bla");
+        const QString desktopNotifications = u"Bla"_s;
         info.desktopNotifications = desktopNotifications;
         job.setUsersSetPreferencesInfo(info);
         QVERIFY(!job.canStart());
 
-        const QByteArray userId = QByteArrayLiteral("foo");
+        const QByteArray userId = "foo"_ba;
         info.userId = userId;
         job.setUsersSetPreferencesInfo(info);
         QCOMPARE(job.json().toJson(QJsonDocument::Compact),
@@ -56,24 +58,24 @@ void UsersSetPreferencesJobTest::shouldNotStarting()
     UsersSetPreferencesJob job;
 
     RestApiMethod method;
-    method.setServerUrl(QStringLiteral("http://www.kde.org"));
+    method.setServerUrl(u"http://www.kde.org"_s);
     job.setRestApiMethod(&method);
 
     QNetworkAccessManager mNetworkAccessManager;
     job.setNetworkAccessManager(&mNetworkAccessManager);
     QVERIFY(!job.canStart());
-    const QString auth = QStringLiteral("foo");
-    const QString userId = QStringLiteral("foo");
+    const QString auth = u"foo"_s;
+    const QString userId = u"foo"_s;
     job.setAuthToken(auth);
     QVERIFY(!job.canStart());
     job.setUserId(userId);
     QVERIFY(!job.canStart());
     UsersSetPreferencesJob::UsersSetPreferencesInfo info;
-    info.desktopNotifications = QStringLiteral("Bla");
+    info.desktopNotifications = u"Bla"_s;
     job.setUsersSetPreferencesInfo(info);
     QVERIFY(!job.canStart());
 
-    info.userId = QByteArrayLiteral("foo");
+    info.userId = "foo"_ba;
     job.setUsersSetPreferencesInfo(info);
     QVERIFY(job.canStart());
 }
