@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "videoconferencecapabilitiesjobtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "restapimethod.h"
 #include "ruqola_restapi_helper.h"
 #include "video-conference/videoconferencecapabilitiesjob.h"
@@ -30,7 +32,7 @@ void VideoConferenceCapabilitiesJobTest::shouldGenerateRequest()
     {
         QNetworkRequest request = QNetworkRequest(QUrl());
         verifyAuthentication(&job, request);
-        QCOMPARE(request.url(), QUrl(QStringLiteral("http://www.kde.org/api/v1/video-conference.capabilities")));
+        QCOMPARE(request.url(), QUrl(u"http://www.kde.org/api/v1/video-conference.capabilities"_s));
     }
 }
 
