@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "setjoincodechanneljob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 #include <QJsonDocument>
 #include <QJsonObject>
 using namespace RocketChatRestApi;
+using namespace Qt::Literals::StringLiterals;
 SetJoinCodeChannelJob::SetJoinCodeChannelJob(QObject *parent)
     : ChannelGroupBaseJob(parent)
 {
@@ -36,11 +36,11 @@ void SetJoinCodeChannelJob::onPostRequestResponse(const QString &replyErrorStrin
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("SetJoinCodeChannelJob success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("SetJoinCodeChannelJob success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT setJoinCodeDone();
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("SetJoinCodeChannelJob problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("SetJoinCodeChannelJob problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
