@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "customsoundslistjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
@@ -13,6 +12,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QJsonObject>
 #include <QUrlQuery>
 using namespace RocketChatRestApi;
+using namespace Qt::Literals::StringLiterals;
 CustomSoundsListJob::CustomSoundsListJob(QObject *parent)
     : RestApiAbstractJob(parent)
 {
@@ -28,7 +28,7 @@ bool CustomSoundsListJob::start()
         return false;
     }
     submitGetRequest();
-    addStartRestApiInfo(QByteArrayLiteral("CustomSoundsJob: Ask custom sounds info"));
+    addStartRestApiInfo("CustomSoundsJob: Ask custom sounds info"_ba);
 
     return true;
 }
@@ -38,11 +38,11 @@ void CustomSoundsListJob::onGetRequestResponse(const QString &replyErrorString,
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("CustomSoundsJob done: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("CustomSoundsJob done: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT customSoundsListDone(replyObject); // TODO fix return value!
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("CustomSoundsJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("CustomSoundsJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
