@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "deletedmjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 DeleteDmJob::DeleteDmJob(QObject *parent)
     : ChannelGroupBaseJob(parent)
@@ -36,12 +36,12 @@ void DeleteDmJob::onPostRequestResponse(const QString &replyErrorString, const Q
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("DeleteDmJob success: ") + replyJson.toJson(QJsonDocument::Indented));
-        qDebug() << " replyObject " << replyObject;
+        addLoggerInfo("DeleteDmJob success: "_ba + replyJson.toJson(QJsonDocument::Indented));
+        // qDebug() << " replyObject " << replyObject;
         Q_EMIT deleteDirectMessagesDone(channelGroupInfo().identifier);
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("DeleteDmJob problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("DeleteDmJob problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
