@@ -1,16 +1,16 @@
 /*
-   SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "changegroupsencryptedjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 ChangeGroupsEncryptedJob::ChangeGroupsEncryptedJob(QObject *parent)
     : ChannelGroupBaseJob(parent)
@@ -36,11 +36,11 @@ void ChangeGroupsEncryptedJob::onPostRequestResponse(const QString &replyErrorSt
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("Change encrypted success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("Change encrypted success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT changeEncryptedDone();
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("Problem when we tried to change encrypted status: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("Problem when we tried to change encrypted status: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
@@ -61,11 +61,11 @@ bool ChangeGroupsEncryptedJob::requireHttpAuthentication() const
 
 bool ChangeGroupsEncryptedJob::canStart() const
 {
-    if (!hasIdentifier()) {
-        qCWarning(ROCKETCHATQTRESTAPI_LOG) << "ChangeGroupsEncryptedJob: RoomId is empty";
+    if (!RestApiAbstractJob::canStart()) {
         return false;
     }
-    if (!RestApiAbstractJob::canStart()) {
+    if (!hasIdentifier()) {
+        qCWarning(ROCKETCHATQTRESTAPI_LOG) << "ChangeGroupsEncryptedJob: RoomId is empty";
         return false;
     }
     return true;
