@@ -64,7 +64,7 @@ QNetworkRequest ModerationUserReportedMessagesJob::request() const
 {
     QUrl url = mRestApiMethod->generateUrl(RestApiUtil::RestApiUrlType::ModerationUserReportedMessages);
     QUrlQuery queryUrl;
-    queryUrl.addQueryItem(QStringLiteral("userId"), QLatin1StringView(mReportedMessageFromUserId));
+    queryUrl.addQueryItem(u"userId"_s, QLatin1StringView(mReportedMessageFromUserId));
     url.setQuery(queryUrl);
     QNetworkRequest request(url);
     addAuthRawHeader(request);
