@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "regeneratepersonalaccesstokenjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 RegeneratePersonalAccessTokenJob::RegeneratePersonalAccessTokenJob(QObject *parent)
     : RestApiAbstractJob(parent)
@@ -37,11 +37,11 @@ void RegeneratePersonalAccessTokenJob::onPostRequestResponse(const QString &repl
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("RegeneratePersonalAccessTokenJob success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("RegeneratePersonalAccessTokenJob success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT regenerateTokenDone(replyObject);
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("RegeneratePersonalAccessTokenJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("RegeneratePersonalAccessTokenJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
