@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "markroomasreadjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 MarkRoomAsReadJob::MarkRoomAsReadJob(QObject *parent)
     : RestApiAbstractJob(parent)
@@ -37,11 +37,11 @@ void MarkRoomAsReadJob::onPostRequestResponse(const QString &replyErrorString, c
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("MarkRoomAsReadJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("MarkRoomAsReadJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT markAsReadDone(mRoomId);
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("MarkRoomAsReadJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("MarkRoomAsReadJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
