@@ -1,11 +1,10 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "teamdeletejob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
@@ -14,6 +13,7 @@ using namespace Qt::Literals::StringLiterals;
 #include <QJsonDocument>
 #include <QJsonObject>
 
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 TeamDeleteJob::TeamDeleteJob(QObject *parent)
     : RestApiAbstractJob(parent)
@@ -39,11 +39,11 @@ void TeamDeleteJob::onPostRequestResponse(const QString &replyErrorString, const
     const QJsonObject replyObject = replyJson.object();
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("TeamDeleteJob success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("TeamDeleteJob success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT deleteTeamDone();
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("TeamDeleteJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("TeamDeleteJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
