@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "deleteuserjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include "rocketchatqtrestapi_debug.h"
 
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 DeleteUserJob::DeleteUserJob(QObject *parent)
     : UserBaseJob(parent)
@@ -37,11 +37,11 @@ void DeleteUserJob::onPostRequestResponse(const QString &replyErrorString, const
     qDebug() << "replyObject " << replyObject;
 
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("DeleteUserJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("DeleteUserJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         Q_EMIT deleteUserDone();
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("DeleteUserJob: Problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("DeleteUserJob: Problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
