@@ -1,15 +1,15 @@
 /*
-   SPDX-FileCopyrightText: 2018-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2018-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "getusernamesuggestionjob.h"
-using namespace Qt::Literals::StringLiterals;
 
 #include "restapimethod.h"
 #include <QJsonDocument>
 #include <QJsonObject>
+using namespace Qt::Literals::StringLiterals;
 using namespace RocketChatRestApi;
 GetUsernameSuggestionJob::GetUsernameSuggestionJob(QObject *parent)
     : RestApiAbstractJob(parent)
@@ -18,14 +18,6 @@ GetUsernameSuggestionJob::GetUsernameSuggestionJob(QObject *parent)
 
 GetUsernameSuggestionJob::~GetUsernameSuggestionJob() = default;
 
-bool GetUsernameSuggestionJob::canStart() const
-{
-    if (!RestApiAbstractJob::canStart()) {
-        return false;
-    }
-    return true;
-}
-
 bool GetUsernameSuggestionJob::start()
 {
     if (!canStart()) {
@@ -41,12 +33,12 @@ void GetUsernameSuggestionJob::onGetRequestResponse(const QString &replyErrorStr
 {
     const QJsonObject replyObject = replyJson.object();
     if (replyObject["success"_L1].toBool()) {
-        addLoggerInfo(QByteArrayLiteral("GetUsernameSuggestionJob: success: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerInfo("GetUsernameSuggestionJob: success: "_ba + replyJson.toJson(QJsonDocument::Indented));
         const QString result = replyObject["result"_L1].toString();
         Q_EMIT getUsernameSuggestionDone(result);
     } else {
         emitFailedMessage(replyErrorString, replyObject);
-        addLoggerWarning(QByteArrayLiteral("GetUsernameSuggestionJob problem: ") + replyJson.toJson(QJsonDocument::Indented));
+        addLoggerWarning("GetUsernameSuggestionJob problem: "_ba + replyJson.toJson(QJsonDocument::Indented));
     }
 }
 
