@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "administratordialog.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "administratorwidget.h"
 
 #include <KConfigGroup>
@@ -26,13 +28,13 @@ AdministratorDialog::AdministratorDialog(RocketChatAccount *account, QWidget *pa
 {
     setWindowTitle(i18nc("@title:window", "Administrator"));
     auto mainLayout = new QVBoxLayout(this);
-    mainLayout->setObjectName(QStringLiteral("mainLayout"));
+    mainLayout->setObjectName(u"mainLayout"_s);
 
-    mAdministratorWidget->setObjectName(QStringLiteral("mAdministratorWidget"));
+    mAdministratorWidget->setObjectName(u"mAdministratorWidget"_s);
     mainLayout->addWidget(mAdministratorWidget);
 
     auto button = new QDialogButtonBox(QDialogButtonBox::Close, this);
-    button->setObjectName(QStringLiteral("button"));
+    button->setObjectName(u"button"_s);
     mainLayout->addWidget(button);
     connect(button, &QDialogButtonBox::rejected, this, &AdministratorDialog::reject);
 
@@ -54,7 +56,7 @@ void AdministratorDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(400, 300));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myAdministratorDialogGroupName));
+    const KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myAdministratorDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
