@@ -5,6 +5,8 @@
 */
 
 #include "administratorcustomsoundscreatedialogtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "administratordialog/customsounds/administratorcustomsoundscreatedialog.h"
 #include "administratordialog/customsounds/administratorcustomsoundscreatewidget.h"
 #include <QDialogButtonBox>
@@ -23,13 +25,13 @@ void AdministratorCustomSoundsCreateDialogTest::shouldHaveDefaultValues()
 {
     AdministratorCustomSoundsCreateDialog w;
     QVERIFY(!w.windowTitle().isEmpty());
-    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
 
-    auto mCreateWidget = w.findChild<AdministratorCustomSoundsCreateWidget *>(QStringLiteral("mCreateWidget"));
+    auto mCreateWidget = w.findChild<AdministratorCustomSoundsCreateWidget *>(u"mCreateWidget"_s);
     QVERIFY(mCreateWidget);
 
-    auto buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("button"));
+    auto buttonBox = w.findChild<QDialogButtonBox *>(u"button"_s);
     QVERIFY(buttonBox);
 }
 
