@@ -5,6 +5,8 @@
 */
 
 #include "administratorinviteuserswidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "administratordialog/users/administratorinviteuserswidget.h"
 #include <QHBoxLayout>
 #include <QLabel>
@@ -20,16 +22,16 @@ void AdministratorInviteUsersWidgetTest::shouldHaveDefaultValues()
 {
     AdministratorInviteUsersWidget w;
 
-    auto mListEmails = w.findChild<QLineEdit *>(QStringLiteral("mListEmails"));
+    auto mListEmails = w.findChild<QLineEdit *>(u"mListEmails"_s);
     QVERIFY(mListEmails);
     QVERIFY(mListEmails->text().isEmpty());
     QVERIFY(!mListEmails->placeholderText().isEmpty());
 
-    auto mainLayout = w.findChild<QHBoxLayout *>(QStringLiteral("formLayout"));
+    auto mainLayout = w.findChild<QHBoxLayout *>(u"formLayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins{});
 
-    auto label = w.findChild<QLabel *>(QStringLiteral("label"));
+    auto label = w.findChild<QLabel *>(u"label"_s);
     QVERIFY(label);
     QVERIFY(!label->text().isEmpty());
 }
