@@ -4,6 +4,8 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "administratormoderationreportedmessageconsoletreewidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "administratordialog/moderationconsole/administratormoderationreportedmessageconsoletreewidget.h"
 #include "administratordialog/moderationconsole/moderationreportedmessageconsoletreewidget.h"
 #include <QTest>
@@ -18,13 +20,13 @@ AdministratorModerationReportedMessageConsoleTreeWidgetTest::AdministratorModera
 void AdministratorModerationReportedMessageConsoleTreeWidgetTest::shouldHaveDefaultValues()
 {
     AdministratorModerationReportedMessageConsoleTreeWidget d(nullptr);
-    auto mainLayout = d.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = d.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->spacing(), 0);
 
-    auto mModerationConsoleTreeWidget = d.findChild<ModerationReportedMessageConsoleTreeWidget *>(QStringLiteral("mModerationConsoleTreeWidget"));
+    auto mModerationConsoleTreeWidget = d.findChild<ModerationReportedMessageConsoleTreeWidget *>(u"mModerationConsoleTreeWidget"_s);
     QVERIFY(mModerationConsoleTreeWidget);
-    auto mAdministratorModerationRangeWidget = d.findChild<AdministratorModerationRangeWidget *>(QStringLiteral("mAdministratorModerationRangeWidget"));
+    auto mAdministratorModerationRangeWidget = d.findChild<AdministratorModerationRangeWidget *>(u"mAdministratorModerationRangeWidget"_s);
     QVERIFY(mAdministratorModerationRangeWidget);
 }
 
