@@ -5,6 +5,8 @@
 */
 
 #include "moderationreportedmessageconsoletreewidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "administratordialog/moderationconsole/moderationmessagesdialog.h"
 #include "connection.h"
 #include "misc/searchwithdelaylineedit.h"
@@ -33,11 +35,11 @@ ModerationReportedMessageConsoleTreeWidget::ModerationReportedMessageConsoleTree
 {
     mCommonMessageFilterProxyModel = new CommonMessageFilterProxyModel(mCommonMessagesModel, this);
     mModel = new ModerationReportedMessageModel(this);
-    mModel->setObjectName(QStringLiteral("mModel"));
+    mModel->setObjectName(u"mModel"_s);
     mSearchLineEdit->setPlaceholderText(i18nc("@info:placeholder", "Search moderation message…"));
 
     mProxyModelModel = new ModerationReportedMessageProxyModel(mModel, this);
-    mProxyModelModel->setObjectName(QStringLiteral("mProxyModelModel"));
+    mProxyModelModel->setObjectName(u"mProxyModelModel"_s);
     mTreeView->setModel(mProxyModelModel);
     connect(this, &ModerationReportedMessageConsoleTreeWidget::doubleClicked, this, &ModerationReportedMessageConsoleTreeWidget::slotShowMessages);
     connect(this, &ModerationReportedMessageConsoleTreeWidget::refreshList, this, [this]() {
@@ -132,21 +134,21 @@ void ModerationReportedMessageConsoleTreeWidget::slotCustomContextMenuRequested(
     if (index.isValid()) {
         QMenu menu(this);
         const QModelIndex newModelIndex = mProxyModelModel->mapToSource(index);
-        menu.addAction(QIcon::fromTheme(QStringLiteral("visibility")), i18nc("@action", "See messages"), this, [this, newModelIndex]() {
+        menu.addAction(QIcon::fromTheme(u"visibility"_s), i18nc("@action", "See messages"), this, [this, newModelIndex]() {
             slotShowMessages(newModelIndex);
         });
         menu.addSeparator();
 
-        menu.addAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18nc("@action", "Dismiss reports"), this, [this, newModelIndex]() {
+        menu.addAction(QIcon::fromTheme(u"list-remove"_s), i18nc("@action", "Dismiss reports"), this, [this, newModelIndex]() {
             const QModelIndex modelIndex = mModel->index(newModelIndex.row(), ModerationReportedMessageModel::UserId);
             slotDismissReport(modelIndex);
         });
-        menu.addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18nc("@action", "Delete all Messages"), this, [this, newModelIndex]() {
+        menu.addAction(QIcon::fromTheme(u"edit-delete"_s), i18nc("@action", "Delete all Messages"), this, [this, newModelIndex]() {
             const QModelIndex modelIndex = mModel->index(newModelIndex.row(), ModerationReportedMessageModel::UserId);
             slotDeleteAllMessages(modelIndex);
         });
         menu.addSeparator();
-        menu.addAction(QIcon::fromTheme(QStringLiteral("list-remove")), i18nc("@action", "Deactivate user"), this, [this, newModelIndex]() {
+        menu.addAction(QIcon::fromTheme(u"list-remove"_s), i18nc("@action", "Deactivate user"), this, [this, newModelIndex]() {
             const QModelIndex modelIndex = mModel->index(newModelIndex.row(), ModerationReportedMessageModel::UserId);
             slotDesactivateUser(modelIndex);
         });
