@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "permissionseditwidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "misc/rolescombobox.h"
 #include <KLocalizedString>
 #include <QHBoxLayout>
@@ -14,11 +16,11 @@ PermissionsEditWidget::PermissionsEditWidget(QWidget *parent)
     , mRolesCombobox(new RolesComboBox(this))
 {
     auto mainLayout = new QHBoxLayout(this);
-    mainLayout->setObjectName(QStringLiteral("mainLayout"));
+    mainLayout->setObjectName(u"mainLayout"_s);
     mainLayout->setContentsMargins({});
     auto label = new QLabel(i18nc("@label:textbox", "Roles:"), this);
-    label->setObjectName(QStringLiteral("label"));
-    mRolesCombobox->setObjectName(QStringLiteral("mRolesCombobox"));
+    label->setObjectName(u"label"_s);
+    mRolesCombobox->setObjectName(u"mRolesCombobox"_s);
     mainLayout->addWidget(label);
     mainLayout->addWidget(mRolesCombobox, 1);
 }
