@@ -4,6 +4,8 @@
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "enterprisesettingswidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "administratorsettingsdialog/enterprise/enterprisesettingswidget.h"
 #include "settingswidgetshelper.h"
 #include <QLabel>
@@ -18,18 +20,18 @@ EnterpriseSettingsWidgetTest::EnterpriseSettingsWidgetTest(QObject *parent)
 void EnterpriseSettingsWidgetTest::shouldHaveDefaultValues()
 {
     EnterpriseSettingsWidget w(nullptr);
-    auto mEnterpriseLicense = w.findChild<QLineEdit *>(QStringLiteral("mEnterpriseLicense"));
+    auto mEnterpriseLicense = w.findChild<QLineEdit *>(u"mEnterpriseLicense"_s);
     QVERIFY(mEnterpriseLicense);
     QVERIFY(mEnterpriseLicense->text().isEmpty());
     QVERIFY(!mEnterpriseLicense->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mEnterpriseLicense), QStringLiteral("Enterprise_License"));
-    SettingsWidgetHelper::checkLabelToolButton(&w, QStringLiteral("Enterprise_License"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mEnterpriseLicense), u"Enterprise_License"_s);
+    SettingsWidgetHelper::checkLabelToolButton(&w, u"Enterprise_License"_s);
 
-    auto mStatus = w.findChild<QLabel *>(QStringLiteral("mStatus"));
+    auto mStatus = w.findChild<QLabel *>(u"mStatus"_s);
     QVERIFY(mStatus);
     QVERIFY(mStatus->text().isEmpty());
     QVERIFY(mStatus->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mStatus), QStringLiteral("Enterprise_License_Status"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mStatus), u"Enterprise_License_Status"_s);
 }
 
 #include "moc_enterprisesettingswidgettest.cpp"
