@@ -5,6 +5,8 @@
 */
 
 #include "troubleshootsettingswidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "administratorsettingsdialog/troubleshoot/troubleshootsettingswidget.h"
 #include "settingswidgetshelper.h"
 #include <QFormLayout>
@@ -19,61 +21,68 @@ void TroubleshootSettingsWidgetTest::shouldHaveDefaultValues()
 {
     TroubleshootSettingsWidget w(nullptr);
 
-    auto mDisableNotifications = w.findChild<QCheckBox *>(QStringLiteral("mDisableNotifications"));
+    auto mDisableNotifications = w.findChild<QCheckBox *>(u"mDisableNotifications"_s);
     QVERIFY(mDisableNotifications);
     QVERIFY(!mDisableNotifications->isChecked());
     QVERIFY(!mDisableNotifications->text().isEmpty());
     QVERIFY(!mDisableNotifications->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableNotifications), QStringLiteral("Troubleshoot_Disable_Notifications"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableNotifications), u"Troubleshoot_Disable_Notifications"_s);
 
-    auto mDisablePresenceBroadcast = w.findChild<QCheckBox *>(QStringLiteral("mDisablePresenceBroadcast"));
+    auto mDisablePresenceBroadcast = w.findChild<QCheckBox *>(u"mDisablePresenceBroadcast"_s);
     QVERIFY(mDisablePresenceBroadcast);
     QVERIFY(!mDisablePresenceBroadcast->isChecked());
     QVERIFY(!mDisablePresenceBroadcast->text().isEmpty());
     QVERIFY(!mDisablePresenceBroadcast->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisablePresenceBroadcast), QStringLiteral("Troubleshoot_Disable_Presence_Broadcast"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisablePresenceBroadcast), u"Troubleshoot_Disable_Presence_Broadcast"_s);
 
-    auto mDisableInstanceBroadcast = w.findChild<QCheckBox *>(QStringLiteral("mDisableInstanceBroadcast"));
+    auto mDisableInstanceBroadcast = w.findChild<QCheckBox *>(u"mDisableInstanceBroadcast"_s);
     QVERIFY(mDisableInstanceBroadcast);
     QVERIFY(!mDisableInstanceBroadcast->isChecked());
     QVERIFY(!mDisableInstanceBroadcast->text().isEmpty());
     QVERIFY(!mDisableInstanceBroadcast->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableInstanceBroadcast), QStringLiteral("Troubleshoot_Disable_Instance_Broadcast"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableInstanceBroadcast), u"Troubleshoot_Disable_Instance_Broadcast"_s);
 
-    auto mDisableSessionsMonitor = w.findChild<QCheckBox *>(QStringLiteral("mDisableSessionsMonitor"));
+    auto mDisableSessionsMonitor = w.findChild<QCheckBox *>(u"mDisableSessionsMonitor"_s);
     QVERIFY(mDisableSessionsMonitor);
     QVERIFY(!mDisableSessionsMonitor->isChecked());
     QVERIFY(!mDisableSessionsMonitor->text().isEmpty());
     QVERIFY(!mDisableSessionsMonitor->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableSessionsMonitor), QStringLiteral("Troubleshoot_Disable_Sessions_Monitor"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableSessionsMonitor), u"Troubleshoot_Disable_Sessions_Monitor"_s);
 
-    auto mDisableLivechatActivityMonitor = w.findChild<QCheckBox *>(QStringLiteral("mDisableLivechatActivityMonitor"));
+    auto mDisableLivechatActivityMonitor = w.findChild<QCheckBox *>(u"mDisableLivechatActivityMonitor"_s);
     QVERIFY(mDisableLivechatActivityMonitor);
     QVERIFY(!mDisableLivechatActivityMonitor->isChecked());
     QVERIFY(!mDisableLivechatActivityMonitor->text().isEmpty());
     QVERIFY(!mDisableLivechatActivityMonitor->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableLivechatActivityMonitor), QStringLiteral("Troubleshoot_Disable_Livechat_Activity_Monitor"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableLivechatActivityMonitor), u"Troubleshoot_Disable_Livechat_Activity_Monitor"_s);
 
-    auto mDisableStatisticsGenerator = w.findChild<QCheckBox *>(QStringLiteral("mDisableStatisticsGenerator"));
+    auto mDisableStatisticsGenerator = w.findChild<QCheckBox *>(u"mDisableStatisticsGenerator"_s);
     QVERIFY(mDisableStatisticsGenerator);
     QVERIFY(!mDisableStatisticsGenerator->isChecked());
     QVERIFY(!mDisableStatisticsGenerator->text().isEmpty());
     QVERIFY(!mDisableStatisticsGenerator->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableStatisticsGenerator), QStringLiteral("Troubleshoot_Disable_Statistics_Generator"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableStatisticsGenerator), u"Troubleshoot_Disable_Statistics_Generator"_s);
 
-    auto mDisableDataExporterProcessor = w.findChild<QCheckBox *>(QStringLiteral("mDisableDataExporterProcessor"));
+    auto mDisableDataExporterProcessor = w.findChild<QCheckBox *>(u"mDisableDataExporterProcessor"_s);
     QVERIFY(mDisableDataExporterProcessor);
     QVERIFY(!mDisableDataExporterProcessor->isChecked());
     QVERIFY(!mDisableDataExporterProcessor->text().isEmpty());
     QVERIFY(!mDisableDataExporterProcessor->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableDataExporterProcessor), QStringLiteral("Troubleshoot_Disable_Data_Exporter_Processor"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableDataExporterProcessor), u"Troubleshoot_Disable_Data_Exporter_Processor"_s);
 
-    auto mDisableWorkspaceSync = w.findChild<QCheckBox *>(QStringLiteral("mDisableWorkspaceSync"));
+    auto mDisableWorkspaceSync = w.findChild<QCheckBox *>(u"mDisableWorkspaceSync"_s);
     QVERIFY(mDisableWorkspaceSync);
     QVERIFY(!mDisableWorkspaceSync->isChecked());
     QVERIFY(!mDisableWorkspaceSync->text().isEmpty());
     QVERIFY(!mDisableWorkspaceSync->toolTip().isEmpty());
-    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableWorkspaceSync), QStringLiteral("Troubleshoot_Disable_Workspace_Sync"));
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableWorkspaceSync), u"Troubleshoot_Disable_Workspace_Sync"_s);
+
+    auto mDisableTeamsMention = w.findChild<QCheckBox *>(u"mDisableTeamsMention"_s);
+    QVERIFY(mDisableTeamsMention);
+    QVERIFY(!mDisableTeamsMention->isChecked());
+    QVERIFY(!mDisableTeamsMention->text().isEmpty());
+    QVERIFY(!mDisableTeamsMention->toolTip().isEmpty());
+    QCOMPARE(SettingsWidgetHelper::widgetSettingsName(mDisableTeamsMention), u"Troubleshoot_Disable_Teams_Mention"_s);
 }
 
 #include "moc_troubleshootsettingswidgettest.cpp"
