@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2022-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2022-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -16,7 +16,7 @@ public:
     explicit EncryptionSettingsWidget(RocketChatAccount *account, QWidget *parent = nullptr);
     ~EncryptionSettingsWidget() override;
 
-    void initialize(const QMap<QString, QVariant> &mapSettings) override;
+    void initialize(const QMap<QString, SettingsWidgetBase::SettingsInfo> &mapSettings) override;
 
 private:
     QCheckBox *const mEnableE2E;
@@ -24,5 +24,6 @@ private:
     QCheckBox *const mEnableEncryptionPrivateRoomsByDefault;
     QCheckBox *const mEnableEncryptFiles;
     QCheckBox *const mAllowUnencryptedMessages;
+    QCheckBox *const mEnableMentions;
     QCheckBox *const mEnableOtr;
 };
