@@ -17,7 +17,7 @@ public:
     explicit RetentionPolicySettingsWidget(RocketChatAccount *account, QWidget *parent = nullptr);
     ~RetentionPolicySettingsWidget() override;
 
-    void initialize(const QMap<QString, QVariant> &mapSettings) override;
+    void initialize(const QMap<QString, SettingsWidgetBase::SettingsInfo> &mapSettings) override;
 
 private:
     QCheckBox *const mEnabled;
