@@ -15,7 +15,7 @@ public:
     explicit VideoConferenceWidget(RocketChatAccount *account, QWidget *parent = nullptr);
     ~VideoConferenceWidget() override;
 
-    void initialize(const QMap<QString, QVariant> &mapSettings) override;
+    void initialize(const QMap<QString, SettingsWidgetBase::SettingsInfo> &mapSettings) override;
 
 private:
     QCheckBox *const mBigBlueEnabled;
