@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
+   SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "authenticationwidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "common/authenticationoauthwidget.h"
 #include <QTest>
 #include <QVBoxLayout>
@@ -18,7 +20,7 @@ AuthenticationWidgetTest::AuthenticationWidgetTest(QWidget *parent)
 void AuthenticationWidgetTest::shouldHaveDefaultValues()
 {
     AuthenticationOauthWidget w;
-    auto mMainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mMainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mMainLayout);
     QCOMPARE(mMainLayout->contentsMargins(), QMargins{});
 }
