@@ -5,6 +5,8 @@
 */
 
 #include "configureaccessibilitywidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "configuredialog/configureaccessibilitywidget.h"
 #include <QTest>
 #include <QVBoxLayout>
@@ -19,11 +21,11 @@ ConfigureAccessibilityWidgetTest::ConfigureAccessibilityWidgetTest(QObject *pare
 void ConfigureAccessibilityWidgetTest::shouldHaveDefaultValues()
 {
     ConfigureAccessibilityWidget w;
-    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins{});
 
-    auto mTextToSpeechWidget = w.findChild<TextEditTextToSpeech::TextToSpeechConfigWidget *>(QStringLiteral("mTextToSpeechWidget"));
+    auto mTextToSpeechWidget = w.findChild<TextEditTextToSpeech::TextToSpeechConfigWidget *>(u"mTextToSpeechWidget"_s);
     QVERIFY(mTextToSpeechWidget);
 }
 
