@@ -1,15 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "configuregeneralwidget.h"
+
 #include "ruqolaglobalconfig.h"
 #include <KLocalizedString>
 #include <QCheckBox>
 #include <QVBoxLayout>
 
+using namespace Qt::Literals::StringLiterals;
 ConfigureGeneralWidget::ConfigureGeneralWidget(QWidget *parent)
     : QWidget(parent)
     , mSetOnlineForAllAccount(new QCheckBox(i18nc("@option:check", "Set status to \"Online\" on startup"), this))
@@ -24,42 +26,46 @@ ConfigureGeneralWidget::ConfigureGeneralWidget(QWidget *parent)
 #if HAVE_ACTIVITY_SUPPORT
     , mEnabledActivitySupport(new QCheckBox(i18nc("@option:check", "Enable Plasma Activities integration"), this))
 #endif
+    , mEnableTextToSpeech(new QCheckBox(i18nc("@option:check", "Enable Text To Speech"), this))
 {
     auto mainLayout = new QVBoxLayout(this);
-    mainLayout->setObjectName(QStringLiteral("mainLayout"));
+    mainLayout->setObjectName(u"mainLayout"_s);
 
-    mSetOnlineForAllAccount->setObjectName(QStringLiteral("mSetOnlineForAllAccount"));
+    mSetOnlineForAllAccount->setObjectName(u"mSetOnlineForAllAccount"_s);
     mainLayout->addWidget(mSetOnlineForAllAccount);
 
-    mShowImageByDefault->setObjectName(QStringLiteral("mShowImageByDefault"));
+    mShowImageByDefault->setObjectName(u"mShowImageByDefault"_s);
     mainLayout->addWidget(mShowImageByDefault);
 
-    mShowPreviewUrlByDefault->setObjectName(QStringLiteral("mShowPreviewUrlByDefault"));
+    mShowPreviewUrlByDefault->setObjectName(u"mShowPreviewUrlByDefault"_s);
     mainLayout->addWidget(mShowPreviewUrlByDefault);
 
-    mMarkAsReadOnTextClicked->setObjectName(QStringLiteral("mMarkAsReadOnTextClicked"));
+    mMarkAsReadOnTextClicked->setObjectName(u"mMarkAsReadOnTextClicked"_s);
     mainLayout->addWidget(mMarkAsReadOnTextClicked);
 
-    mEnableSystemTray->setObjectName(QStringLiteral("mEnableSystemTray"));
+    mEnableSystemTray->setObjectName(u"mEnableSystemTray"_s);
     mainLayout->addWidget(mEnableSystemTray);
 
-    mEnableLogging->setObjectName(QStringLiteral("mEnableLogging"));
+    mEnableLogging->setObjectName(u"mEnableLogging"_s);
     mainLayout->addWidget(mEnableLogging);
 
-    mShowHoverHightLights->setObjectName(QStringLiteral("mShowHoverHightLights"));
+    mShowHoverHightLights->setObjectName(u"mShowHoverHightLights"_s);
     mainLayout->addWidget(mShowHoverHightLights);
 
-    mAnimateGif->setObjectName(QStringLiteral("mAnimateGif"));
+    mAnimateGif->setObjectName(u"mAnimateGif"_s);
     mainLayout->addWidget(mAnimateGif);
 
-    mStoreMessageInDataBase->setObjectName(QStringLiteral("mStoreMessageInDataBase"));
+    mStoreMessageInDataBase->setObjectName(u"mStoreMessageInDataBase"_s);
     mainLayout->addWidget(mStoreMessageInDataBase);
 
 #if HAVE_ACTIVITY_SUPPORT
-    mEnabledActivitySupport->setObjectName(QStringLiteral("mEnabledActivitySupport"));
+    mEnabledActivitySupport->setObjectName(u"mEnabledActivitySupport"_s);
     mainLayout->addWidget(mEnabledActivitySupport);
 #endif
 
+    mEnableTextToSpeech->setObjectName(u"mEnableTextToSpeech"_s);
+    mainLayout->addWidget(mEnableTextToSpeech);
+
     mainLayout->addStretch(1);
 }
 
@@ -79,6 +85,7 @@ void ConfigureGeneralWidget::save()
 #if HAVE_ACTIVITY_SUPPORT
     RuqolaGlobalConfig::self()->setPlasmaActivities(mEnabledActivitySupport->isChecked());
 #endif
+    RuqolaGlobalConfig::self()->setEnableTextToSpeech(mEnableTextToSpeech->isChecked());
     RuqolaGlobalConfig::self()->save();
 }
 
@@ -96,6 +103,7 @@ void ConfigureGeneralWidget::load()
 #if HAVE_ACTIVITY_SUPPORT
     mEnabledActivitySupport->setChecked(RuqolaGlobalConfig::self()->plasmaActivities());
 #endif
+    mEnableTextToSpeech->setChecked(RuqolaGlobalConfig::self()->enableTextToSpeech());
 }
 
 #include "moc_configuregeneralwidget.cpp"
