@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "addusersinroomdialogtest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "dialogs/addusersinroomdialog.h"
 #include "dialogs/addusersinroomwidget.h"
 #include <QDialogButtonBox>
@@ -23,13 +25,13 @@ void AddUsersInRoomDialogTest::shouldHaveDefaultValues()
 {
     AddUsersInRoomDialog w(nullptr);
     QVERIFY(!w.windowTitle().isEmpty());
-    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
 
-    auto mAddUsersInRoomWidget = w.findChild<AddUsersInRoomWidget *>(QStringLiteral("mAddUsersInRoomWidget"));
+    auto mAddUsersInRoomWidget = w.findChild<AddUsersInRoomWidget *>(u"mAddUsersInRoomWidget"_s);
     QVERIFY(mAddUsersInRoomWidget);
 
-    auto buttonBox = w.findChild<QDialogButtonBox *>(QStringLiteral("button"));
+    auto buttonBox = w.findChild<QDialogButtonBox *>(u"button"_s);
     QVERIFY(buttonBox);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     QVERIFY(okButton);
