@@ -5,6 +5,8 @@
 */
 
 #include "createnewdiscussionwidgettest.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "dialogs/channelsearchnamelineedit.h"
 #include "dialogs/channelsearchwidget.h"
 #include "dialogs/createnewdiscussionwidget.h"
@@ -25,39 +27,39 @@ CreateNewDiscussionWidgetTest::CreateNewDiscussionWidgetTest(QObject *parent)
 void CreateNewDiscussionWidgetTest::shouldHaveDefaultValues()
 {
     CreateNewDiscussionWidget w(nullptr);
-    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
     QCOMPARE(mainLayout->contentsMargins(), QMargins{});
 
-    auto channelLabel = w.findChild<QLabel *>(QStringLiteral("channelLabel"));
+    auto channelLabel = w.findChild<QLabel *>(u"channelLabel"_s);
     QVERIFY(channelLabel);
     QVERIFY(!channelLabel->text().isEmpty());
 
-    auto mChannelNameLineEdit = w.findChild<ChannelSearchWidget *>(QStringLiteral("mChannelNameLineEdit"));
+    auto mChannelNameLineEdit = w.findChild<ChannelSearchWidget *>(u"mChannelNameLineEdit"_s);
     QVERIFY(mChannelNameLineEdit);
 
-    auto discussionName = w.findChild<QLabel *>(QStringLiteral("discussionName"));
+    auto discussionName = w.findChild<QLabel *>(u"discussionName"_s);
     QVERIFY(discussionName);
     QVERIFY(!discussionName->text().isEmpty());
 
-    auto mDiscussionNameLineEdit = w.findChild<QLineEdit *>(QStringLiteral("mDiscussionNameLineEdit"));
+    auto mDiscussionNameLineEdit = w.findChild<QLineEdit *>(u"mDiscussionNameLineEdit"_s);
     QVERIFY(mDiscussionNameLineEdit);
     QVERIFY(mDiscussionNameLineEdit->text().isEmpty());
     QVERIFY(mDiscussionNameLineEdit->isClearButtonEnabled());
 
-    auto usersLabel = w.findChild<QLabel *>(QStringLiteral("usersLabel"));
+    auto usersLabel = w.findChild<QLabel *>(u"usersLabel"_s);
     QVERIFY(usersLabel);
     QVERIFY(!usersLabel->text().isEmpty());
 
-    auto mUsers = w.findChild<AddUsersWidget *>(QStringLiteral("mUsers"));
+    auto mUsers = w.findChild<AddUsersWidget *>(u"mUsers"_s);
     QVERIFY(mUsers);
     QVERIFY(mUsers->userIds().isEmpty());
 
-    auto messageLabel = w.findChild<QLabel *>(QStringLiteral("messageLabel"));
+    auto messageLabel = w.findChild<QLabel *>(u"messageLabel"_s);
     QVERIFY(messageLabel);
     QVERIFY(!messageLabel->text().isEmpty());
 
-    auto mMessageTextEdit = w.findChild<KTextEdit *>(QStringLiteral("mMessageTextEdit"));
+    auto mMessageTextEdit = w.findChild<KTextEdit *>(u"mMessageTextEdit"_s);
     QVERIFY(mMessageTextEdit);
     QVERIFY(mMessageTextEdit->toPlainText().isEmpty());
     QVERIFY(!mMessageTextEdit->acceptRichText());
