@@ -1,10 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "showthreadsdialogtest.h"
+using namespace Qt::Literals::StringLiterals;
+
+#include "dialogs/showtheadscombobox.h"
 #include "dialogs/showthreadsdialog.h"
 #include <QDialogButtonBox>
 #include <QStandardPaths>
@@ -23,11 +26,14 @@ void ShowThreadsDialogTest::shouldHaveDefaultValues()
     ShowThreadsDialog w(nullptr);
     QVERIFY(!w.windowTitle().isEmpty());
 
-    auto mainLayout = w.findChild<QVBoxLayout *>(QStringLiteral("mainLayout"));
+    auto mainLayout = w.findChild<QVBoxLayout *>(u"mainLayout"_s);
     QVERIFY(mainLayout);
 
-    auto button = w.findChild<QDialogButtonBox *>(QStringLiteral("button"));
+    auto button = w.findChild<QDialogButtonBox *>(u"button"_s);
     QVERIFY(button);
+
+    auto mShowTheadsComboBox = w.findChild<ShowTheadsComboBox *>(u"mShowTheadsComboBox"_s);
+    QVERIFY(mShowTheadsComboBox);
 }
 
 #include "moc_showthreadsdialogtest.cpp"
