@@ -5,6 +5,8 @@
 */
 
 #include "channelinfodialog.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "channelinfowidget.h"
 #include "room.h"
 
@@ -19,7 +21,7 @@
 
 namespace
 {
-static const char myConfigChannelInfoDialogGroupName[] = "ChannelInfoDialog";
+const char myConfigChannelInfoDialogGroupName[] = "ChannelInfoDialog";
 }
 
 ChannelInfoDialog::ChannelInfoDialog(Room *room, RocketChatAccount *account, QWidget *parent)
@@ -29,9 +31,9 @@ ChannelInfoDialog::ChannelInfoDialog(Room *room, RocketChatAccount *account, QWi
 {
     setWindowTitle(i18nc("@title:window", "Channel Info"));
     auto mainLayout = new QVBoxLayout(this);
-    mainLayout->setObjectName(QStringLiteral("mainLayout"));
+    mainLayout->setObjectName(u"mainLayout"_s);
 
-    mChannelInfoWidget->setObjectName(QStringLiteral("mChannelInfoWidget"));
+    mChannelInfoWidget->setObjectName(u"mChannelInfoWidget"_s);
     mainLayout->addWidget(mChannelInfoWidget);
     mChannelInfoWidget->updateUiFromPermission();
 
@@ -74,7 +76,7 @@ void ChannelInfoDialog::readConfig()
 {
     create(); // ensure a window is created
     windowHandle()->resize(QSize(600, 400));
-    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myConfigChannelInfoDialogGroupName));
+    const KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1StringView(myConfigChannelInfoDialogGroupName));
     KWindowConfig::restoreWindowSize(windowHandle(), group);
     resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
