@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "channelnamevalidlineedit.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "rocketchataccount.h"
 
 #include "connection.h"
@@ -69,7 +71,7 @@ void ChannelNameValidLineEdit::updateStyleSheet(bool state)
     QString styleSheet;
     if (mNegativeBackground.isEmpty()) {
         const KStatefulBrush bgBrush(KColorScheme::View, KColorScheme::NegativeBackground);
-        mNegativeBackground = QStringLiteral("QLineEdit{ background-color:%1 }").arg(bgBrush.brush(palette()).color().name());
+        mNegativeBackground = u"QLineEdit{ background-color:%1 }"_s.arg(bgBrush.brush(palette()).color().name());
     }
     if (!state) {
         styleSheet = mNegativeBackground;
