@@ -1,10 +1,12 @@
 /*
-   SPDX-FileCopyrightText: 2021-2024 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2021-2025 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "channelsearchnamelineresultwidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include <KLocalizedString>
 #include <QHBoxLayout>
 #include <QLabel>
@@ -16,14 +18,14 @@ ChannelSearchNameLineResultWidget::ChannelSearchNameLineResultWidget(QWidget *pa
     , mClearToolButton(new QToolButton(this))
 {
     auto mainLayout = new QHBoxLayout(this);
-    mainLayout->setObjectName(QStringLiteral("mainLayout"));
+    mainLayout->setObjectName(u"mainLayout"_s);
     mainLayout->setContentsMargins({});
 
-    mLabel->setObjectName(QStringLiteral("mLabel"));
+    mLabel->setObjectName(u"mLabel"_s);
     mainLayout->addWidget(mLabel);
 
-    mClearToolButton->setObjectName(QStringLiteral("mClearToolButton"));
-    mClearToolButton->setIcon(QIcon::fromTheme(QStringLiteral("delete")));
+    mClearToolButton->setObjectName(u"mClearToolButton"_s);
+    mClearToolButton->setIcon(QIcon::fromTheme(u"delete"_s));
     mClearToolButton->setToolTip(i18nc("@info:tooltip", "Clear"));
     mainLayout->addWidget(mClearToolButton);
     connect(mClearToolButton, &QToolButton::clicked, this, &ChannelSearchNameLineResultWidget::clearRoomName);
