@@ -5,6 +5,8 @@
 */
 
 #include "configurenotificationwidget.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "misc/soundconfigurewidget.h"
 #include "model/notificationdesktopsoundpreferencemodel.h"
 #include "model/notificationpreferencemodel.h"
@@ -12,20 +14,17 @@
 #include "rocketchataccount.h"
 #include "room.h"
 #include <KLocalizedString>
-#include <QAudioOutput>
 #include <QCheckBox>
 #include <QComboBox>
 #include <QFormLayout>
 #include <QGroupBox>
-#include <QMediaPlayer>
-#include <QToolButton>
 #include <QVBoxLayout>
 
 ConfigureNotificationWidget::ConfigureNotificationWidget(RocketChatAccount *account, QWidget *parent)
     : QWidget(parent)
     , mDisableNotification(new QCheckBox(i18nc("@option:check", "Disable Notification"), this))
     , mHideUnreadRoomStatus(new QCheckBox(i18nc("@option:check", "Hide Unread Room Status"), this))
-    , mMuteGroupMentions(new QCheckBox(i18nc("@option:check", "Mute %1 and %2 mentions", QStringLiteral("@all"), QStringLiteral("@here")), this))
+    , mMuteGroupMentions(new QCheckBox(i18nc("@option:check", "Mute %1 and %2 mentions", u"@all"_s, u"@here"_s), this))
     , mShowBadgeMentions(new QCheckBox(i18nc("@option:check", "Show badge for mentions"), this))
     , mDesktopAlertCombobox(new QComboBox(this))
     , mDesktopSoundConfigureWidget(new SoundConfigureWidget(account, this))
@@ -34,29 +33,29 @@ ConfigureNotificationWidget::ConfigureNotificationWidget(RocketChatAccount *acco
     , mRocketChatAccount(account)
 {
     auto topLayout = new QVBoxLayout(this);
-    topLayout->setObjectName(QStringLiteral("topLayout"));
+    topLayout->setObjectName(u"topLayout"_s);
     topLayout->setContentsMargins({});
 
-    mDisableNotification->setObjectName(QStringLiteral("mDisableNotification"));
+    mDisableNotification->setObjectName(u"mDisableNotification"_s);
     mDisableNotification->setToolTip(i18nc("@info:tooltip", "Receive alerts"));
     topLayout->addWidget(mDisableNotification);
     connect(mDisableNotification, &QCheckBox::clicked, this, [this](bool checked) {
         mRocketChatAccount->changeNotificationsSettings(mRoom->roomId(), RocketChatAccount::NotificationOptionsType::DisableNotifications, checked);
     });
 
-    mHideUnreadRoomStatus->setObjectName(QStringLiteral("mHideUnreadRoomStatus"));
+    mHideUnreadRoomStatus->setObjectName(u"mHideUnreadRoomStatus"_s);
     topLayout->addWidget(mHideUnreadRoomStatus);
     connect(mHideUnreadRoomStatus, &QCheckBox::clicked, this, [this](bool checked) {
         mRocketChatAccount->changeNotificationsSettings(mRoom->roomId(), RocketChatAccount::NotificationOptionsType::HideUnreadStatus, checked);
     });
 
-    mMuteGroupMentions->setObjectName(QStringLiteral("mMuteGroupMentions"));
+    mMuteGroupMentions->setObjectName(u"mMuteGroupMentions"_s);
     topLayout->addWidget(mMuteGroupMentions);
     connect(mMuteGroupMentions, &QCheckBox::clicked, this, [this](bool checked) {
         mRocketChatAccount->changeNotificationsSettings(mRoom->roomId(), RocketChatAccount::NotificationOptionsType::MuteGroupMentions, checked);
     });
 
-    mShowBadgeMentions->setObjectName(QStringLiteral("mShowBadgeMentions"));
+    mShowBadgeMentions->setObjectName(u"mShowBadgeMentions"_s);
     mShowBadgeMentions->setToolTip(i18nc("@info:tooltip", "Display badge for direct mentions only"));
     topLayout->addWidget(mShowBadgeMentions);
     connect(mShowBadgeMentions, &QCheckBox::clicked, this, [this](bool checked) {
@@ -64,13 +63,13 @@ ConfigureNotificationWidget::ConfigureNotificationWidget(RocketChatAccount *acco
     });
 
     auto desktopGroupBox = new QGroupBox(i18n("Desktop"), this);
-    desktopGroupBox->setObjectName(QStringLiteral("desktopGroupBox"));
+    desktopGroupBox->setObjectName(u"desktopGroupBox"_s);
     topLayout->addWidget(desktopGroupBox);
 
     auto desktopGroupBoxLayout = new QFormLayout(desktopGroupBox);
-    desktopGroupBoxLayout->setObjectName(QStringLiteral("desktopGroupBoxLayout"));
+    desktopGroupBoxLayout->setObjectName(u"desktopGroupBoxLayout"_s);
 
-    mDesktopAlertCombobox->setObjectName(QStringLiteral("mDesktopAlertCombobox"));
+    mDesktopAlertCombobox->setObjectName(u"mDesktopAlertCombobox"_s);
     desktopGroupBoxLayout->addRow(i18n("Alert:"), mDesktopAlertCombobox);
     if (mRocketChatAccount) {
         mDesktopAlertCombobox->setModel(mRocketChatAccount->notificationPreferences()->desktopNotificationModel());
@@ -86,7 +85,7 @@ ConfigureNotificationWidget::ConfigureNotificationWidget(RocketChatAccount *acco
     soundLayout->setSpacing(0);
     soundLayout->addWidget(mDesktopSoundConfigureWidget);
 
-    mDesktopSoundConfigureWidget->setObjectName(QStringLiteral("mDesktopSoundConfigureWidget"));
+    mDesktopSoundConfigureWidget->setObjectName(u"mDesktopSoundConfigureWidget"_s);
     desktopGroupBoxLayout->addRow(i18n("Sound:"), soundLayout);
     if (mRocketChatAccount) {
         mDesktopSoundConfigureWidget->setSoundModel(mRocketChatAccount->notificationPreferences()->desktopSoundNotificationModel());
@@ -97,13 +96,13 @@ ConfigureNotificationWidget::ConfigureNotificationWidget(RocketChatAccount *acco
     });
 
     auto mobileGroupBox = new QGroupBox(i18n("Mobile"), this);
-    mobileGroupBox->setObjectName(QStringLiteral("mobileGroupBox"));
+    mobileGroupBox->setObjectName(u"mobileGroupBox"_s);
     topLayout->addWidget(mobileGroupBox);
 
     auto mobileGroupBoxLayout = new QFormLayout(mobileGroupBox);
-    mobileGroupBoxLayout->setObjectName(QStringLiteral("mobileGroupBoxLayout"));
+    mobileGroupBoxLayout->setObjectName(u"mobileGroupBoxLayout"_s);
 
-    mMobileAlertCombobox->setObjectName(QStringLiteral("mMobileAlertCombobox"));
+    mMobileAlertCombobox->setObjectName(u"mMobileAlertCombobox"_s);
     mobileGroupBoxLayout->addRow(i18n("Alert:"), mMobileAlertCombobox);
     if (mRocketChatAccount) {
         mMobileAlertCombobox->setModel(mRocketChatAccount->notificationPreferences()->mobileNotificationModel());
@@ -115,13 +114,13 @@ ConfigureNotificationWidget::ConfigureNotificationWidget(RocketChatAccount *acco
     });
 
     auto emailGroupBox = new QGroupBox(i18n("Email"), this);
-    emailGroupBox->setObjectName(QStringLiteral("emailGroupBox"));
+    emailGroupBox->setObjectName(u"emailGroupBox"_s);
     topLayout->addWidget(emailGroupBox);
 
     auto emailGroupBoxLayout = new QFormLayout(emailGroupBox);
-    emailGroupBoxLayout->setObjectName(QStringLiteral("emailGroupBoxLayout"));
+    emailGroupBoxLayout->setObjectName(u"emailGroupBoxLayout"_s);
 
-    mEmailAlertCombobox->setObjectName(QStringLiteral("mEmailAlertCombobox"));
+    mEmailAlertCombobox->setObjectName(u"mEmailAlertCombobox"_s);
     emailGroupBoxLayout->addRow(i18n("Alert:"), mEmailAlertCombobox);
     if (mRocketChatAccount) {
         mEmailAlertCombobox->setModel(mRocketChatAccount->notificationPreferences()->emailNotificationModel());
