@@ -143,7 +143,7 @@ void SearchMessageWidget::slotSearchMessagesFailed()
 
 void SearchMessageWidget::slotLoadHistory()
 {
-    messageSearch(mSearchLineEdit->text(), mRoomId, true, mOffset);
+    messageSearch(mSearchLineEdit->text(), mRoomId, false, mOffset);
     mOffset += numberOfElment;
 }
 
@@ -160,7 +160,7 @@ void SearchMessageWidget::slotSearchMessages(const QString &str)
         clearSearchModel();
         mSearchMessageFilterProxyModel->setSearchText(str);
         mSearchLineEdit->addCompletionItem(str);
-        messageSearch(str, mRoomId, true);
+        messageSearch(str, mRoomId, false);
         mOffset = numberOfElment;
     }
 }
