@@ -5,6 +5,11 @@
 */
 
 #include "showimagewidget.h"
+#include <kio/applicationlauncherjob.h>
+#include <kio/jobuidelegatefactory.h>
+#include <kjobuidelegate.h>
+using namespace Qt::Literals::StringLiterals;
+
 #include "common/delegateutil.h"
 #include "connection.h"
 #include "rocketchataccount.h"
@@ -35,10 +40,10 @@ ShowImageWidget::ShowImageWidget(RocketChatAccount *account, QWidget *parent)
     , mRocketChatAccount(account)
 {
     auto mainLayout = new QVBoxLayout(this);
-    mainLayout->setObjectName(QStringLiteral("mainLayout"));
+    mainLayout->setObjectName(u"mainLayout"_s);
     mainLayout->setContentsMargins({});
 
-    mImageGraphicsView->setObjectName(QStringLiteral("mImageGraphicsView"));
+    mImageGraphicsView->setObjectName(u"mImageGraphicsView"_s);
     mainLayout->addWidget(mImageGraphicsView);
     connect(mImageGraphicsView, &ShowImageGraphicsView::zoomChanged, this, [this](qreal zoom) {
         mSlider->setValue(static_cast<int>(zoom * 100));
@@ -47,13 +52,13 @@ ShowImageWidget::ShowImageWidget(RocketChatAccount *account, QWidget *parent)
     connect(mImageGraphicsView, &ShowImageGraphicsView::minimumZoomChanged, this, &ShowImageWidget::updateRanges);
     connect(mImageGraphicsView, &ShowImageGraphicsView::maximumZoomChanged, this, &ShowImageWidget::updateRanges);
 
-    mZoomControls->setObjectName(QStringLiteral("zoomControls"));
+    mZoomControls->setObjectName(u"zoomControls"_s);
     auto zoomLayout = new QHBoxLayout;
-    zoomLayout->setObjectName(QStringLiteral("zoomLayout"));
+    zoomLayout->setObjectName(u"zoomLayout"_s);
     mZoomControls->setLayout(zoomLayout);
     mainLayout->addWidget(mZoomControls);
 
-    mShowImagePrevNextImageWidget->setObjectName(QStringLiteral("mShowImagePrevNextImageWidget"));
+    mShowImagePrevNextImageWidget->setObjectName(u"mShowImagePrevNextImageWidget"_s);
     zoomLayout->addWidget(mShowImagePrevNextImageWidget);
     mShowImagePrevNextImageWidget->setVisible(false); // hide by default
 
@@ -61,31 +66,31 @@ ShowImageWidget::ShowImageWidget(RocketChatAccount *account, QWidget *parent)
     connect(mShowImagePrevNextImageWidget, &ShowImagePrevNextImageWidget::showPreviousImage, this, &ShowImageWidget::slotShowPreviousImage);
 
     auto label = new QLabel(i18nc("@label:textbox", "Zoom:"), this);
-    label->setObjectName(QStringLiteral("zoomLabel"));
+    label->setObjectName(u"zoomLabel"_s);
     label->setTextFormat(Qt::PlainText);
     zoomLayout->addWidget(label);
 
-    mZoomSpin->setObjectName(QStringLiteral("mZoomSpin"));
+    mZoomSpin->setObjectName(u"mZoomSpin"_s);
 
     mZoomSpin->setValue(1);
     mZoomSpin->setDecimals(1);
     mZoomSpin->setSingleStep(0.1);
     zoomLayout->addWidget(mZoomSpin);
 
-    mSlider->setObjectName(QStringLiteral("mSlider"));
+    mSlider->setObjectName(u"mSlider"_s);
     mSlider->setOrientation(Qt::Horizontal);
     zoomLayout->addWidget(mSlider);
     mSlider->setValue(mZoomSpin->value() * 100.0);
 
     auto resetButton = new QPushButton(i18nc("@action:button", "100%"), this);
-    resetButton->setObjectName(QStringLiteral("resetButton"));
+    resetButton->setObjectName(u"resetButton"_s);
     zoomLayout->addWidget(resetButton);
     connect(resetButton, &QPushButton::clicked, this, [this] {
         mImageGraphicsView->setZoom(1.0);
     });
 
     auto fitToViewButton = new QPushButton(i18nc("@action:button", "Fit to View"), this);
-    fitToViewButton->setObjectName(QStringLiteral("fitToViewButton"));
+    fitToViewButton->setObjectName(u"fitToViewButton"_s);
     zoomLayout->addWidget(fitToViewButton);
     connect(fitToViewButton, &QPushButton::clicked, mImageGraphicsView, &ShowImageGraphicsView::fitToView);
 
@@ -167,6 +172,7 @@ void ShowImageWidget::slotFileDownloaded(const QString &filePath, const QUrl &ca
         const QString cacheImageUrlPath{cacheImageUrl.toLocalFile()};
         const QPixmap pixmap(cacheImageUrlPath);
         mImageGraphicsView->updatePixmap(pixmap, cacheImageUrlPath);
+        Q_EMIT updateMenu(info);
     }
 }
 
@@ -186,6 +192,7 @@ void ShowImageWidget::updateButtons()
 void ShowImageWidget::setImageInfo(const ShowImageWidget::ImageInfo &info)
 {
     mImageGraphicsView->setImageInfo(info);
+    Q_EMIT updateMenu(info);
 }
 
 const ShowImageWidget::ImageInfo &ShowImageWidget::imageInfo() const
@@ -204,7 +211,7 @@ void ShowImageWidget::copyImage()
 {
     auto data = new QMimeData();
     data->setImageData(mImageGraphicsView->pixmap().toImage());
-    data->setData(QStringLiteral("x-kde-force-image-copy"), QByteArray());
+    data->setData(u"x-kde-force-image-copy"_s, QByteArray());
     QApplication::clipboard()->setMimeData(data, QClipboard::Clipboard);
 }
 
@@ -249,6 +256,16 @@ void ShowImageWidget::showImages(const QByteArray &fileId, const QByteArray &roo
     }
 }
 
+void ShowImageWidget::openWith(const KService::Ptr &service)
+{
+    const QString imagePath = mRocketChatAccount->attachmentUrlFromLocalCache(mImageGraphicsView->imageInfo().bigImagePath).toLocalFile();
+    // If service is null, ApplicationLauncherJob will invoke the open-with dialog
+    auto job = new KIO::ApplicationLauncherJob(service);
+    job->setUrls({QUrl::fromLocalFile(imagePath)});
+    job->setUiDelegate(KIO::createDefaultJobUiDelegate(KJobUiDelegate::AutoHandlingEnabled, this));
+    job->start();
+}
+
 ShowImageWidget::ImageInfo ShowImageWidget::ImageListInfo::imageFromIndex(int index, RocketChatAccount *account) const
 {
     if (!imageAttachments.isEmpty() && (index < imageAttachments.count())) {
